# -*- coding: cp1251 -*-
# Проект: КОМПАС-Макро
# Модуль: MiscellaneousHelpers.py (Различные функции - помошники)
# Дата создания: 07.11.2008
# Дата последнего изменения: 13.11.2008
# Автор: Архипов Александр (АСКОН-Курган)
#
import pythoncom
from win32com.client import Dispatch, gencache

kompas6_constants = gencache.EnsureModule("{75C9F5D0-B5B8-4526-8681-9903C567D2ED}", 0, 1, 0).constants

# Точность сравнения равенства вещественных чисел
DoublePrecition = 1.0e-11

# Ограничение по количеству точек сравнения для ломаных
MaxNumberOfPointsToCompareArrays = 10

# Проверка на равенство 2-х вещественных чисел
def DoubleEqualTo(double1, double2):
    return abs(double1 - double2) <= 2 * DoublePrecition

# Ищет ссылку отрезка
def GetLineSegReference (X1, Y1, X2, Y2, Style):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrLineSeg, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksLineSegParam = iKompasObject.GetParamStruct(kompas6_constants.ko_LineSegParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksLineSegParam, kompas6_constants.ksAllParam)
        if DoubleEqualTo(iksLineSegParam.x1, X1) and \
           DoubleEqualTo(iksLineSegParam.y1, Y1) and \
           DoubleEqualTo(iksLineSegParam.x2, X2) and \
           DoubleEqualTo(iksLineSegParam.y2, Y2) and \
           iksLineSegParam.style == Style : \
           break
        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine


# Ищет ссылку линии
def GetLineReference (X, Y, Angle):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrLine, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksLineParam = iKompasObject.GetParamStruct(kompas6_constants.ko_LineParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksLineParam, kompas6_constants.ksAllParam)
        if DoubleEqualTo(iksLineParam.x, X) and \
           DoubleEqualTo(iksLineParam.y, Y) and \
           DoubleEqualTo(iksLineParam.angle, Angle): \
           break
        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine

# Ищет ссылку окружности
def GetCircleReference (X, Y, Radius, Style):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrCircle, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksCircleParam = iKompasObject.GetParamStruct(kompas6_constants.ko_CircleParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksCircleParam, kompas6_constants.ksAllParam)
        if DoubleEqualTo(iksCircleParam.xc, X) and \
           DoubleEqualTo(iksCircleParam.yc, Y) and \
           DoubleEqualTo(iksCircleParam.rad, Radius) and \
           iksCircleParam.style == Style: \
           break
        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine

# Ищет ссылку прямоугольника
def GetRectangleReference (X, Y, Angle, Height, Width, Style):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrRectangle, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksRectangleParam = iKompasObject.GetParamStruct(kompas6_constants.ko_RectangleParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksRectangleParam, kompas6_constants.ksAllParam)
        if DoubleEqualTo(iksRectangleParam.x, X) and \
           DoubleEqualTo(iksRectangleParam.y, Y) and \
           DoubleEqualTo(iksRectangleParam.ang, Angle) and \
           DoubleEqualTo(iksRectangleParam.height, Height) and \
           DoubleEqualTo(iksRectangleParam.width, Width) and \
           iksRectangleParam.style == Style: \
           break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine

# Ищет ссылку эллипса
def GetEllipseReference (X, Y, A, B, Angle, Style):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrEllipse, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksEllipseParam = iKompasObject.GetParamStruct(kompas6_constants.ko_EllipseParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksEllipseParam, kompas6_constants.ksAllParam)
        if DoubleEqualTo(iksEllipseParam.xc, X) and \
           DoubleEqualTo(iksEllipseParam.yc, Y) and \
           DoubleEqualTo(iksEllipseParam.A, A) and \
           DoubleEqualTo(iksEllipseParam.B, B) and \
           DoubleEqualTo(iksEllipseParam.angle, Angle) and \
           iksEllipseParam.style == Style: \
           break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine

# Ищет ссылку дуги
def GetArcReference (X, Y, Radius, Angle1, Angle2, Direction, Style):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrArc, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksArcByAngleParam = iKompasObject.GetParamStruct(kompas6_constants.ko_ArcByAngleParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksArcByAngleParam, kompas6_constants.ksAllParam)
        if DoubleEqualTo(iksArcByAngleParam.xc, X) and \
           DoubleEqualTo(iksArcByAngleParam.yc, Y) and \
           DoubleEqualTo(iksArcByAngleParam.rad, Radius) and \
           DoubleEqualTo(iksArcByAngleParam.ang1, Angle1) and \
           DoubleEqualTo(iksArcByAngleParam.ang2, Angle2) and \
           iksArcByAngleParam.dir == Direction and \
           iksArcByAngleParam.style == Style: \
           break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine

# Сравнение массива точек типа ksDynamicArray с данным кортежем точек
# число сравниваемых точек не превышает MaximumNumberOfPoints
def DynamicArrayHasPoints(iksDynamicArray, ko_PointParam, Points, MaximumNumberOfPoints):
    if iksDynamicArray.ksGetArrayCount() != len(Points) :
        return False
    for i in range(min(len(Points), MaximumNumberOfPoints)):
        iksPointParam = iKompasObject.GetParamStruct(ko_PointParam)
        iksDynamicArray.ksGetArrayItem(i, iksPointParam)
        if not DoubleEqualTo(iksPointParam.x, Points[i][0]) or not DoubleEqualTo(iksPointParam.y, Points[i][1]) :
            return False
    return True

# Ищет ссылку ломаной
def GetPolylineReference (Points):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrPolyline, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksPolylineParam = iKompasObject.GetParamStruct(kompas6_constants.ko_PolylineParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksPolylineParam, kompas6_constants.ksAllParam)
        iksDynamicArray = iksPolylineParam.GetpMathPoint()
        if DynamicArrayHasPoints(iksDynamicArray, kompas6_constants.ko_MathPointParam, Points, MaxNumberOfPointsToCompareArrays) : break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine


# Ищет ссылку сплайна Безье
def GetBezierSplineReference (Points):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrBezier, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksBezierParam = iKompasObject.GetParamStruct(kompas6_constants.ko_BezierParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksBezierParam, kompas6_constants.ksAllParam)
        iksDynamicArray = iksBezierParam.GetMathPointArr()
        if DynamicArrayHasPoints(iksDynamicArray, kompas6_constants.ko_MathPointParam, Points, MaxNumberOfPointsToCompareArrays) : break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine


"""
# Ищет ссылку стрелки направления взгляда
def GetWPointerReference (X1, Y1, X2, Y2, XT, YT, Type, String, Style):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrWPointer, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksViewPointerParam = iKompasObject.GetParamStruct(kompas6_constants.ko_ViewPointerParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksViewPointerParam, kompas6_constants.ksAllParam)
        if  DoubleEqualTo(iksViewPointerParam.x1, X1) and \
            DoubleEqualTo(iksViewPointerParam.y1, Y1) and \
            DoubleEqualTo(iksViewPointerParam.x2, X2) and \
            DoubleEqualTo(iksViewPointerParam.y2, Y2) and \
            DoubleEqualTo(iksViewPointerParam.xt, XT) and \
            DoubleEqualTo(iksViewPointerParam.yt, YT) and \
            iksViewPointerParam.type == Type and \
            iksViewPointerParam.str == String and \
            iksViewPointerParam.style == Style :
            break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine
"""

# Ищет ссылку NURBS сплайна
def GetNurbsSplineReference (Points):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrNurbs, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksNurbsParam = iKompasObject.GetParamStruct(kompas6_constants.ko_NurbsParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksNurbsParam, kompas6_constants.ksAllParam)
        iksDynamicArray = iksNurbsParam.GetPPoint()
        if DynamicArrayHasPoints(iksDynamicArray, kompas6_constants.ko_NurbsPointParam, Points, MaxNumberOfPointsToCompareArrays) : break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine


# Ищет эквидистанту
"""
def GetEquidistantReference (X1, Y1, X2, Y2, XT, YT, Type, String, Style):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrWPointer, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksViewPointerParam = iKompasObject.GetParamStruct(kompas6_constants.ko_ViewPointerParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksViewPointerParam, kompas6_constants.ksAllParam)
        if  DoubleEqualTo(iksViewPointerParam.x1, X1) and \
            DoubleEqualTo(iksViewPointerParam.y1, Y1) and \
            DoubleEqualTo(iksViewPointerParam.x2, X2) and \
            DoubleEqualTo(iksViewPointerParam.y2, Y2) and \
            DoubleEqualTo(iksViewPointerParam.xt, XT) and \
            DoubleEqualTo(iksViewPointerParam.yt, YT) and \
            iksViewPointerParam.type == Type and \
            iksViewPointerParam.str == String and \
            iksViewPointerParam.style == Style :
            break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine
"""

# Ищет ссылку осевой линии
def GetAxisLineReference (X1, Y1, X2, Y2):
    iDocument2D = iKompasObject.ActiveDocument2D()

    iIterator = iKompasObject.GetIterator()
    iIterator.ksCreateIterator(kompas6_constants.ksDrAxisLine, 0)
    refLine = iIterator.ksMoveIterator('F')
    iksAxisLineParam = iKompasObject.GetParamStruct(kompas6_constants.ko_AxisLineParam)

    while refLine != 0:
        iDocument2D.ksGetObjParam(refLine, iksAxisLineParam, kompas6_constants.ksAllParam)
        if DoubleEqualTo(iksAxisLineParam.GetBegPoint().x, X1) and \
           DoubleEqualTo(iksAxisLineParam.GetBegPoint().y, Y1) and \
           DoubleEqualTo(iksAxisLineParam.GetEndPoint().x, X2) and \
           DoubleEqualTo(iksAxisLineParam.GetEndPoint().y, Y2) :
           break

        refLine = iIterator.ksMoveIterator('N')

    iIterator.ksDeleteIterator()
    return refLine


# Ищет интерфейс прямой координационной оси
def GetStraightAxis (X1, Y1, X2, Y2, Length, Angle):
    iDocument = iApplication.ActiveDocument
    iKompasDocument2D = KAPI7.IKompasDocument2D(iDocument)

    iViewsAndLayersManager = iKompasDocument2D.ViewsAndLayersManager
    iViews = iViewsAndLayersManager.Views
    iView = iViews.ActiveView
    iBuildingContainer = iView._oleobj_.QueryInterface(KAPI7.NamesToIIDMap['IBuildingContainer'], pythoncom.IID_IDispatch)
    iBuildingContainer = KAPI7.IBuildingContainer(iBuildingContainer)
    iBuildingAxes = iBuildingContainer.BuildingAxes
    iStraightAxis = 0
    for i in range(iBuildingAxes.Count) :
        iStraightAxis = iBuildingAxes.BuildingAxis(i)
        if iStraightAxis.Type == kompas6_constants.ksObjectStraightAxis :
            iStraightAxis = KAPI7.IStraightAxis(iStraightAxis)
            if DoubleEqualTo(iStraightAxis.X1, X1) and\
               DoubleEqualTo(iStraightAxis.Y1, Y1) and\
               DoubleEqualTo(iStraightAxis.X2, X2) and\
               DoubleEqualTo(iStraightAxis.Y2, Y2) and\
               DoubleEqualTo(iStraightAxis.Length, Length) and\
               DoubleEqualTo(iStraightAxis.Angle, Angle):
                break
    return iStraightAxis


# Ищет интерфейс круговой координационной оси
def GetCircleAxis (X, Y, Radius):
    iDocument = iApplication.ActiveDocument
    iKompasDocument2D = KAPI7.IKompasDocument2D(iDocument)

    iViewsAndLayersManager = iKompasDocument2D.ViewsAndLayersManager
    iViews = iViewsAndLayersManager.Views
    iView = iViews.ActiveView
    iBuildingContainer = iView._oleobj_.QueryInterface(KAPI7.NamesToIIDMap['IBuildingContainer'], pythoncom.IID_IDispatch)
    iBuildingContainer = KAPI7.IBuildingContainer(iBuildingContainer)
    iBuildingAxes = iBuildingContainer.BuildingAxes
    iCircleAxis = 0
    for i in range(iBuildingAxes.Count) :
        iCircleAxis = iBuildingAxes.BuildingAxis(i)
        if iCircleAxis.Type == kompas6_constants.ksObjectCircleAxis :
            iCircleAxis = KAPI7.ICircleAxis(iCircleAxis)
            if DoubleEqualTo(iCircleAxis.Xc, X) and\
               DoubleEqualTo(iCircleAxis.Yc, Y) and\
               DoubleEqualTo(iCircleAxis.Radius, Radius):
                break
    return iCircleAxis


# Ищет интерфейс дуговой координационной оси
def GetArcAxis (X1, Y1, X2, Y2, X3, Y3, Xc, Yc, Radius, Angle1, Angle2, Direction):
    iDocument = iApplication.ActiveDocument
    iKompasDocument2D = KAPI7.IKompasDocument2D(iDocument)

    iViewsAndLayersManager = iKompasDocument2D.ViewsAndLayersManager
    iViews = iViewsAndLayersManager.Views
    iView = iViews.ActiveView
    iBuildingContainer = iView._oleobj_.QueryInterface(KAPI7.NamesToIIDMap['IBuildingContainer'], pythoncom.IID_IDispatch)
    iBuildingContainer = KAPI7.IBuildingContainer(iBuildingContainer)
    iBuildingAxes = iBuildingContainer.BuildingAxes
    iArcAxis = 0
    for i in range(iBuildingAxes.Count) :
        iArcAxis = iBuildingAxes.BuildingAxis(i)
        if iArcAxis.Type == kompas6_constants.ksObjectArcAxis :
            iArcAxis= KAPI7.IArcAxis(iArcAxis)
            if DoubleEqualTo(iArcAxis.X1, X1) and\
               DoubleEqualTo(iArcAxis.Y1, Y1) and\
               DoubleEqualTo(iArcAxis.X2, X2) and\
               DoubleEqualTo(iArcAxis.Y2, Y2) and\
               DoubleEqualTo(iArcAxis.X3, X3) and\
               DoubleEqualTo(iArcAxis.Y3, Y3) and\
               DoubleEqualTo(iArcAxis.Xc, Xc) and\
               DoubleEqualTo(iArcAxis.Yc, Yc) and\
               DoubleEqualTo(iArcAxis.Radius, Radius) and\
               DoubleEqualTo(iArcAxis.Angle1, Angle1) and\
               DoubleEqualTo(iArcAxis.Angle2, Angle2) and\
               iArcAxis.Direction == Direction :
                break
    return iArcAxis



# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# From type library 'ConvertLibInterfaces.tlb'
# On Fri Nov  5 08:11:40 2021
''
makepy_version = '0.5.01'
python_version = 0x30802f0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{BC89C6E1-8016-429C-A093-300B3F18DB21}')
MajorVersion = 1
MinorVersion = 0
LibraryFlags = 8
LCID = 0x0

class constants:
	ksECRChangeSection            =4          # from enum ksExecuteCommandResult
	ksECRNeedRefreshTree          =1          # from enum ksExecuteCommandResult
	ksECRRepeatCommand            =2          # from enum ksExecuteCommandResult
	ksECRSuccess                  =0          # from enum ksExecuteCommandResult

from win32com.client import DispatchBaseClass
class IExternalElementsBase(DispatchBaseClass):
	'Внешняя база элементов.'
	CLSID = IID('{A4FBAA00-BAA1-4D26-AFF3-91B3FBC76F13}')
	coclass_clsid = None

	def DrawElement(self, HWnd=defaultNamedNotOptArg):
		'Отрисовать в окне просмотра выбранный элемент.'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (11, 0), ((3, 1),),HWnd
			)

	def ExecuteCommand(self, CommandID=defaultNamedNotOptArg):
		'Выполнить комманду.'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (3, 0), ((3, 1),),CommandID
			)

	def GetCommandState(self, CommandID=defaultNamedNotOptArg, Enable=pythoncom.Missing, Checked=pythoncom.Missing):
		'Получить состояние команд панели и меню.'
		return self._ApplyTypes_(10, 1, (11, 0), ((3, 1), (16395, 2), (16395, 2)), 'GetCommandState', None,CommandID
			, Enable, Checked)

	def GetLibPropertyObject(self):
		'Получить указатель на интерфейс параметров текущего элемента - ILibPropertyObject.'
		ret = self._oleobj_.InvokeTypes(7, LCID, 1, (13, 0), (),)
		if ret is not None:
			# See if this IUnknown is really an IDispatch
			try:
				ret = ret.QueryInterface(pythoncom.IID_IDispatch)
			except pythoncom.error:
				return ret
			ret = Dispatch(ret, 'GetLibPropertyObject', None)
		return ret

	def GetMenuId(self):
		'Получить идентификатор меню для текущего листа дерева.'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (3, 0), (),)

	def OnSelectNode(self, NodeId=defaultNamedNotOptArg):
		'Событие установки текущего листа дерева.'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),NodeId
			)

	# The method TreeImageList is actually a property, but must be used as a method to correctly pass the arguments
	def TreeImageList(self, Size=defaultNamedNotOptArg):
		'Получить линейку иконок для дерева.'
		return self._ApplyTypes_(8, 2, (12, 0), ((3, 1),), 'TreeImageList', None,Size
			)

	_prop_map_get_ = {
		"CurrentNode": (5, 2, (8, 0), (), "CurrentNode", None),
		"CurrentSection": (3, 2, (8, 0), (), "CurrentSection", None),
		"ElementsTree": (4, 2, (8, 0), (), "ElementsTree", None),
		"Note": (14, 2, (8, 0), (), "Note", None),
		"Sections": (2, 2, (12, 0), (), "Sections", None),
		"ToolBarId": (9, 2, (3, 0), (), "ToolBarId", None),
		"Version": (1, 2, (3, 0), (), "Version", None),
	}
	_prop_map_put_ = {
		"CurrentSection": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKompasConverter(DispatchBaseClass):
	CLSID = IID('{735140E9-F6B5-42E9-9008-71730C617067}')
	coclass_clsid = None

	def Convert(self, inputFile=defaultNamedNotOptArg, outfile=defaultNamedNotOptArg, command=defaultNamedNotOptArg, showParam=defaultNamedNotOptArg):
		'Запустить процесс конвертации'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), ((8, 1), (8, 1), (3, 1), (11, 1)),inputFile
			, outfile, command, showParam)

	def ConverterParameters(self, command=defaultNamedNotOptArg):
		'Параметры конвертора'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (13, 0), ((3, 1),),command
			)
		if ret is not None:
			# See if this IUnknown is really an IDispatch
			try:
				ret = ret.QueryInterface(pythoncom.IID_IDispatch)
			except pythoncom.error:
				return ret
			ret = Dispatch(ret, 'ConverterParameters', None)
		return ret

	def GetFilter(self, docType=defaultNamedNotOptArg, saveAs=defaultNamedNotOptArg, command=pythoncom.Missing):
		"Получить фильтр и номер команды по типу документа 'КОМПАС-Фрагменты (*.frw)|*.frw|'"
		return self._ApplyTypes_(3, 1, (8, 0), ((3, 1), (11, 1), (16387, 2)), 'GetFilter', None,docType
			, saveAs, command)

	def VisualEditConvertParam(self, parentHwnd=defaultNamedNotOptArg, command=defaultNamedNotOptArg):
		'Запустить визуальное редактирование параметров конвертации'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1), (3, 1)),parentHwnd
			, command)

	_prop_map_get_ = {
		"CanUnloadLibrary": (2, 2, (11, 0), (), "CanUnloadLibrary", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

IExternalElementsBase_vtables_dispatch_ = 1
IExternalElementsBase_vtables_ = [
	(( 'Version' , 'Result' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( 'Sections' , 'Result' , ), 2, (2, (), [ (16396, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( 'CurrentSection' , 'Result' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( 'CurrentSection' , 'Result' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( 'ElementsTree' , 'Result' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( 'CurrentNode' , 'NodeId' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( 'OnSelectNode' , 'NodeId' , 'Result' , ), 6, (6, (), [ (8, 1, None, None) , 
			 (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( 'GetLibPropertyObject' , 'Result' , ), 7, (7, (), [ (16397, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( 'TreeImageList' , 'Size' , 'Result' , ), 8, (8, (), [ (3, 1, None, None) , 
			 (16396, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( 'ToolBarId' , 'Result' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( 'GetCommandState' , 'CommandID' , 'Enable' , 'Checked' , 'Result' , 
			 ), 10, (10, (), [ (3, 1, None, None) , (16395, 2, None, None) , (16395, 2, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( 'ExecuteCommand' , 'CommandID' , 'Result' , ), 11, (11, (), [ (3, 1, None, None) , 
			 (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( 'GetMenuId' , 'Result' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( 'DrawElement' , 'HWnd' , 'Result' , ), 13, (13, (), [ (3, 1, None, None) , 
			 (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( 'Note' , 'Result' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
]

IKompasConverter_vtables_dispatch_ = 1
IKompasConverter_vtables_ = [
	(( 'ConverterParameters' , 'command' , 'iParam' , ), 1, (1, (), [ (3, 1, None, None) , 
			 (16397, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( 'CanUnloadLibrary' , 'val' , ), 2, (2, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( 'GetFilter' , 'docType' , 'saveAs' , 'command' , 'Result' , 
			 ), 3, (3, (), [ (3, 1, None, None) , (11, 1, None, None) , (16387, 2, None, None) , (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( 'Convert' , 'inputFile' , 'outfile' , 'command' , 'showParam' , 
			 'Result' , ), 4, (4, (), [ (8, 1, None, None) , (8, 1, None, None) , (3, 1, None, None) , 
			 (11, 1, None, None) , (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( 'VisualEditConvertParam' , 'parentHwnd' , 'command' , 'val' , ), 5, (5, (), [ 
			 (3, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

RecordMap = {
}

CLSIDToClassMap = {
	'{735140E9-F6B5-42E9-9008-71730C617067}' : IKompasConverter,
	'{A4FBAA00-BAA1-4D26-AFF3-91B3FBC76F13}' : IExternalElementsBase,
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
	'{735140E9-F6B5-42E9-9008-71730C617067}' : 'IKompasConverter',
	'{A4FBAA00-BAA1-4D26-AFF3-91B3FBC76F13}' : 'IExternalElementsBase',
}


NamesToIIDMap = {
	'IKompasConverter' : '{735140E9-F6B5-42E9-9008-71730C617067}',
	'IExternalElementsBase' : '{A4FBAA00-BAA1-4D26-AFF3-91B3FBC76F13}',
}

win32com.client.constants.__dicts__.append(constants.__dict__)




# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# From type library 'IFCConverter.tlb'
# On Fri Nov  5 08:12:38 2021
''
makepy_version = '0.5.01'
python_version = 0x30802f0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{31EBF650-BD38-43EC-892B-1F8AC6C14431}')
MajorVersion = 1
MinorVersion = 0
LibraryFlags = 8
LCID = 0x0

from win32com.client import DispatchBaseClass
class IIFCConverterParam(DispatchBaseClass):
	'Параметры конвертера'
	CLSID = IID('{1BF78A7C-E274-4B61-8771-EBD0542E8F05}')
	coclass_clsid = None

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

IIFCConverterParam_vtables_dispatch_ = 1
IIFCConverterParam_vtables_ = [
]

RecordMap = {
}

CLSIDToClassMap = {
	'{1BF78A7C-E274-4B61-8771-EBD0542E8F05}' : IIFCConverterParam,
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
	'{1BF78A7C-E274-4B61-8771-EBD0542E8F05}' : 'IIFCConverterParam',
}


NamesToIIDMap = {
	'IIFCConverterParam' : '{1BF78A7C-E274-4B61-8771-EBD0542E8F05}',
}





# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# From type library 'KompasLibrary.tlb'
# On Fri Nov  5 08:14:41 2021
''
makepy_version = '0.5.01'
python_version = 0x30802f0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{C1633829-7BB0-4E69-8ED4-043ADB7E8090}')
MajorVersion = 1
MinorVersion = 0
LibraryFlags = 8
LCID = 0x0

class constants:
	ksLFBeginUnloadLibrary        =17010      # from enum ksKompasLibraryFunctionEnum
	ksLFContextPanelStyleComboChanged=17015      # from enum ksKompasLibraryFunctionEnum
	ksLFCreateMacroFromSample     =17017      # from enum ksKompasLibraryFunctionEnum
	ksLFDisplayLibraryName        =17004      # from enum ksKompasLibraryFunctionEnum
	ksLFFillContextPanel          =17014      # from enum ksKompasLibraryFunctionEnum
	ksLFFillLibraryMenu           =17011      # from enum ksKompasLibraryFunctionEnum
	ksLFGetDisableReason          =17013      # from enum ksKompasLibraryFunctionEnum
	ksLFGetKompasConverter        =17016      # from enum ksKompasLibraryFunctionEnum
	ksLFGetLibraryCommandState    =17012      # from enum ksKompasLibraryFunctionEnum
	ksLFInitLibrary               =17009      # from enum ksKompasLibraryFunctionEnum
	ksLFIsFunctionEnable          =17002      # from enum ksKompasLibraryFunctionEnum
	ksLFIsOnApplication7          =17008      # from enum ksKompasLibraryFunctionEnum
	ksLFLibraryHelpFile           =17005      # from enum ksKompasLibraryFunctionEnum
	ksLFLibraryName               =17003      # from enum ksKompasLibraryFunctionEnum
	ksLFProtectNumber             =17006      # from enum ksKompasLibraryFunctionEnum
	ksLFRunLibraryCommand         =17007      # from enum ksKompasLibraryFunctionEnum
	ksLFVersion                   =17001      # from enum ksKompasLibraryFunctionEnum

from win32com.client import DispatchBaseClass
class IKompasLibrary(DispatchBaseClass):
	'Интерфейс приложения Компас 3D.'
	CLSID = IID('{025A21B0-0192-4A7C-A3F0-CA54AAA4FADB}')
	coclass_clsid = None

	def BeginUnloadLibrary(self):
		'Завершающие действия перед отключением библиотеки, отписка от событий.'
		return self._oleobj_.InvokeTypes(17010, LCID, 1, (11, 0), (),)

	def ContextPanelStyleComboChanged(self, StyleComboID=defaultNamedNotOptArg, styleType=defaultNamedNotOptArg, newValue=defaultNamedNotOptArg):
		'Изменение значения в стилевом комбобоксе контекстной панели.'
		return self._oleobj_.InvokeTypes(17015, LCID, 1, (11, 0), ((8, 1), (3, 1), (3, 1)),StyleComboID
			, styleType, newValue)

	def CreateMacroFromSample(self, MacroReference=defaultNamedNotOptArg):
		'Создать объект по образцу.'
		return self._oleobj_.InvokeTypes(17017, LCID, 1, (11, 0), ((3, 1),),MacroReference
			)

	def FillContextPanel(self, ContextPanel=defaultNamedNotOptArg):
		'Накачка всплывающей панели для библиотечных элементов.'
		return self._oleobj_.InvokeTypes(17014, LCID, 1, (11, 0), ((9, 1),),ContextPanel
			)

	def FillLibraryMenu(self, Menu=defaultNamedNotOptArg):
		'Динамическая накачка меню.'
		return self._oleobj_.InvokeTypes(17011, LCID, 1, (11, 0), ((9, 1),),Menu
			)

	def GetDisableReason(self, Command=defaultNamedNotOptArg):
		'Получить описание причины недоступности команды.'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(17013, LCID, 1, (8, 0), ((3, 1),),Command
			)

	def GetKompasConverter(self):
		'Получить интерфейс конвертора.'
		ret = self._oleobj_.InvokeTypes(17016, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, 'GetKompasConverter', None)
		return ret

	def GetLibraryCommandState(self, Command=defaultNamedNotOptArg, Enable=pythoncom.Missing, Checked=pythoncom.Missing):
		'Получить текущее состояние команды.'
		return self._ApplyTypes_(17012, 1, (11, 0), ((3, 1), (16395, 2), (16387, 2)), 'GetLibraryCommandState', None,Command
			, Enable, Checked)

	def InitLibrary(self, ApplicationInterface=defaultNamedNotOptArg):
		'Инициализация библиотеки, подписка на события.'
		return self._oleobj_.InvokeTypes(17009, LCID, 1, (11, 0), ((9, 1),),ApplicationInterface
			)

	# The method IsFunctionEnable is actually a property, but must be used as a method to correctly pass the arguments
	def IsFunctionEnable(self, FunctionID=defaultNamedNotOptArg):
		'Признак поддержки библиотекой функций.'
		return self._oleobj_.InvokeTypes(17002, LCID, 2, (11, 0), ((3, 1),),FunctionID
			)

	def RunLibraryCommand(self, Command=defaultNamedNotOptArg, DemoMode=defaultNamedNotOptArg):
		'Выполнить команду библиотеки.'
		return self._oleobj_.InvokeTypes(17007, LCID, 1, (3, 0), ((3, 1), (3, 1)),Command
			, DemoMode)

	_prop_map_get_ = {
		"DisplayLibraryName": (17004, 2, (8, 0), (), "DisplayLibraryName", None),
		"IsOnApplication7": (17008, 2, (11, 0), (), "IsOnApplication7", None),
		"LibraryHelpFile": (17005, 2, (8, 0), (), "LibraryHelpFile", None),
		"LibraryName": (17003, 2, (8, 0), (), "LibraryName", None),
		"ProtectNumber": (17006, 2, (3, 0), (), "ProtectNumber", None),
		"Version": (17001, 2, (3, 0), (), "Version", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKompasLibraryMenu(DispatchBaseClass):
	'Меню библиотеки.'
	CLSID = IID('{C35D07D7-0248-40C5-A335-1D4FF1610F0A}')
	coclass_clsid = None

	def AddMenuCommand(self, Id=defaultNamedNotOptArg, Title=defaultNamedNotOptArg):
		'Добавить пункт меню.'
		return self._oleobj_.InvokeTypes(18001, LCID, 1, (11, 0), ((3, 1), (8, 1)),Id
			, Title)

	def AddSeparator(self):
		'Добавить разделитель.'
		return self._oleobj_.InvokeTypes(18002, LCID, 1, (11, 0), (),)

	def AddSubMenu(self, Title=defaultNamedNotOptArg):
		'Добавить подменю.'
		return self._oleobj_.InvokeTypes(18003, LCID, 1, (11, 0), ((8, 1),),Title
			)

	def EndSubMenu(self):
		'Добавить подменю.'
		return self._oleobj_.InvokeTypes(18004, LCID, 1, (11, 0), (),)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ksKompasLibrary(DispatchBaseClass):
	'Интерфейс приложения КОМПАС 3D.'
	CLSID = IID('{C222614E-AB59-4FEE-9F4A-1EAB7C1D4C5E}')
	coclass_clsid = None

	def ContextPanelStyleComboChanged(self, StyleComboID=defaultNamedNotOptArg, styleType=defaultNamedNotOptArg, newValue=defaultNamedNotOptArg):
		'Изменение значения в стилевом комбобоксе контекстной панели.'
		return self._oleobj_.InvokeTypes(16015, LCID, 1, (11, 0), ((8, 1), (3, 1), (3, 1)),StyleComboID
			, styleType, newValue)

	def CreateMacroFromSample(self, MacroReference=defaultNamedNotOptArg):
		'Создать объект по оброзцу.'
		return self._oleobj_.InvokeTypes(16016, LCID, 1, (11, 0), ((3, 1),),MacroReference
			)

	def DisplayLibraryName(self):
		'Отображаемое имя приложения.'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16002, LCID, 1, (8, 0), (),)

	def ExternalGetMenu(self):
		'Получить меню библиотеки.'
		return self._oleobj_.InvokeTypes(16009, LCID, 1, (3, 0), (),)

	def ExternalMenuItem(self, Index=defaultNamedNotOptArg, ItemType=pythoncom.Missing, Command=pythoncom.Missing):
		'Динамическая накачка меню.'
		return self._ApplyTypes_(16010, 1, (8, 0), ((2, 1), (16386, 2), (16386, 2)), 'ExternalMenuItem', None,Index
			, ItemType, Command)

	def ExternalRunCommand(self, Command=defaultNamedNotOptArg, mode=defaultNamedNotOptArg, ApplicationInterface=defaultNamedNotOptArg):
		'Выполнить команду библиотеки.'
		return self._oleobj_.InvokeTypes(16005, LCID, 1, (24, 0), ((2, 1), (2, 1), (9, 0)),Command
			, mode, ApplicationInterface)

	def FillContextPanel(self, ContextPanel=defaultNamedNotOptArg):
		'Накачка всплывающей панели для библиотечных элементов.'
		return self._oleobj_.InvokeTypes(16014, LCID, 1, (11, 0), ((9, 1),),ContextPanel
			)

	def GetDisableReason(self, Command=defaultNamedNotOptArg):
		'Получить описание причины недоступности команды.'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16013, LCID, 1, (8, 0), ((3, 1),),Command
			)

	def GetHelpFile(self):
		'Файл справки.'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16003, LCID, 1, (8, 0), (),)

	def GetIKompasConverter(self):
		'Получить интерфейс конвертора.'
		ret = self._oleobj_.InvokeTypes(16011, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, 'GetIKompasConverter', None)
		return ret

	def GetLibraryName(self):
		'Имя приложения.'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16001, LCID, 1, (8, 0), (),)

	def GetProtectNumber(self):
		'Номер ключа защиты.'
		return self._oleobj_.InvokeTypes(16004, LCID, 1, (2, 0), (),)

	def IsOnApplication7(self):
		'Получить тип версии API используемого библиотекой.'
		return self._oleobj_.InvokeTypes(16006, LCID, 1, (11, 0), (),)

	def LibInterfaceNotifyDisconnect(self):
		'Завершающие действия перед отключением библиотеки, отписка от событий.'
		return self._oleobj_.InvokeTypes(16008, LCID, 1, (11, 0), (),)

	def LibInterfaceNotifyEntry(self, ApplicationInterface=defaultNamedNotOptArg):
		'Инициализация библиотеки, подписка на события.'
		return self._oleobj_.InvokeTypes(16007, LCID, 1, (11, 0), ((9, 1),),ApplicationInterface
			)

	def LibraryCommandState(self, Command=defaultNamedNotOptArg, Enable=pythoncom.Missing, Checked=pythoncom.Missing):
		'Получить текущее состояние команды.'
		return self._ApplyTypes_(16012, 1, (11, 0), ((3, 1), (16395, 2), (16387, 2)), 'LibraryCommandState', None,Command
			, Enable, Checked)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

IKompasLibrary_vtables_dispatch_ = 1
IKompasLibrary_vtables_ = [
	(( 'Version' , 'Result' , ), 17001, (17001, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( 'IsFunctionEnable' , 'FunctionID' , 'Result' , ), 17002, (17002, (), [ (3, 1, None, None) , 
			 (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( 'LibraryName' , 'Result' , ), 17003, (17003, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( 'DisplayLibraryName' , 'Result' , ), 17004, (17004, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( 'LibraryHelpFile' , 'Result' , ), 17005, (17005, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( 'ProtectNumber' , 'Result' , ), 17006, (17006, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( 'RunLibraryCommand' , 'Command' , 'DemoMode' , 'Result' , ), 17007, (17007, (), [ 
			 (3, 1, None, None) , (3, 1, None, None) , (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( 'IsOnApplication7' , 'Result' , ), 17008, (17008, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( 'InitLibrary' , 'ApplicationInterface' , 'Result' , ), 17009, (17009, (), [ (9, 1, None, None) , 
			 (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( 'BeginUnloadLibrary' , 'Result' , ), 17010, (17010, (), [ (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( 'FillLibraryMenu' , 'Menu' , 'Result' , ), 17011, (17011, (), [ (9, 1, None, "IID('{C35D07D7-0248-40C5-A335-1D4FF1610F0A}')") , 
			 (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( 'GetLibraryCommandState' , 'Command' , 'Enable' , 'Checked' , 'Result' , 
			 ), 17012, (17012, (), [ (3, 1, None, None) , (16395, 2, None, None) , (16387, 2, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( 'GetDisableReason' , 'Command' , 'Result' , ), 17013, (17013, (), [ (3, 1, None, None) , 
			 (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( 'FillContextPanel' , 'ContextPanel' , 'Result' , ), 17014, (17014, (), [ (9, 1, None, None) , 
			 (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( 'ContextPanelStyleComboChanged' , 'StyleComboID' , 'styleType' , 'newValue' , 'Result' , 
			 ), 17015, (17015, (), [ (8, 1, None, None) , (3, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( 'GetKompasConverter' , 'Result' , ), 17016, (17016, (), [ (16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( 'CreateMacroFromSample' , 'MacroReference' , 'Result' , ), 17017, (17017, (), [ (3, 1, None, None) , 
			 (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
]

IKompasLibraryMenu_vtables_dispatch_ = 1
IKompasLibraryMenu_vtables_ = [
	(( 'AddMenuCommand' , 'Id' , 'Title' , 'Result' , ), 18001, (18001, (), [ 
			 (3, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( 'AddSeparator' , 'Result' , ), 18002, (18002, (), [ (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( 'AddSubMenu' , 'Title' , 'Result' , ), 18003, (18003, (), [ (8, 1, None, None) , 
			 (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( 'EndSubMenu' , 'Result' , ), 18004, (18004, (), [ (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

RecordMap = {
}

CLSIDToClassMap = {
	'{025A21B0-0192-4A7C-A3F0-CA54AAA4FADB}' : IKompasLibrary,
	'{C35D07D7-0248-40C5-A335-1D4FF1610F0A}' : IKompasLibraryMenu,
	'{C222614E-AB59-4FEE-9F4A-1EAB7C1D4C5E}' : ksKompasLibrary,
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
	'{025A21B0-0192-4A7C-A3F0-CA54AAA4FADB}' : 'IKompasLibrary',
	'{C35D07D7-0248-40C5-A335-1D4FF1610F0A}' : 'IKompasLibraryMenu',
}


NamesToIIDMap = {
	'IKompasLibrary' : '{025A21B0-0192-4A7C-A3F0-CA54AAA4FADB}',
	'IKompasLibraryMenu' : '{C35D07D7-0248-40C5-A335-1D4FF1610F0A}',
	'ksKompasLibrary' : '{C222614E-AB59-4FEE-9F4A-1EAB7C1D4C5E}',
}

win32com.client.constants.__dicts__.append(constants.__dict__)




# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# From type library 'ksConstants3D.tlb'
# On Fri Nov  5 08:15:10 2021
''
makepy_version = '0.5.01'
python_version = 0x30802f0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{2CAF168C-7961-4B90-9DA2-701419BEEFE3}')
MajorVersion = 1
MinorVersion = 0
LibraryFlags = 8
LCID = 0x0

class constants:
	format_C3D                    =7          # from enum D3FormatConvType
	format_IGES                   =4          # from enum D3FormatConvType
	format_JT                     =8          # from enum D3FormatConvType
	format_SAT                    =1          # from enum D3FormatConvType
	format_STEP                   =3          # from enum D3FormatConvType
	format_STEP_AP203             =203        # from enum D3FormatConvType
	format_STEP_AP214             =214        # from enum D3FormatConvType
	format_STEP_AP242             =242        # from enum D3FormatConvType
	format_STL                    =6          # from enum D3FormatConvType
	format_Unknown                =0          # from enum D3FormatConvType
	format_VRML                   =5          # from enum D3FormatConvType
	format_XT                     =2          # from enum D3FormatConvType
	load_format_C3D               =-7         # from enum D3FormatConvType
	load_format_CATIA             =-104       # from enum D3FormatConvType
	load_format_CREO              =-101       # from enum D3FormatConvType
	load_format_IGES              =-4         # from enum D3FormatConvType
	load_format_INV               =-103       # from enum D3FormatConvType
	load_format_JT                =-8         # from enum D3FormatConvType
	load_format_NX                =-100       # from enum D3FormatConvType
	load_format_SAT               =-1         # from enum D3FormatConvType
	load_format_SE                =-105       # from enum D3FormatConvType
	load_format_STEP              =-3         # from enum D3FormatConvType
	load_format_STL               =-6         # from enum D3FormatConvType
	load_format_SW                =-102       # from enum D3FormatConvType
	load_format_XT                =-2         # from enum D3FormatConvType
	dtBoth                        =2          # from enum Direction_Type
	dtMiddlePlane                 =3          # from enum Direction_Type
	dtNormal                      =0          # from enum Direction_Type
	dtReverse                     =1          # from enum Direction_Type
	etBlind                       =0          # from enum End_Type
	etThroughAll                  =1          # from enum End_Type
	etUpToNearSurface             =6          # from enum End_Type
	etUpToSurfaceFrom             =5          # from enum End_Type
	etUpToSurfaceTo               =4          # from enum End_Type
	etUpToVertexFrom              =3          # from enum End_Type
	etUpToVertexTo                =2          # from enum End_Type
	et3dAbort                     =-1         # from enum ErrorType3d
	et3dError1                    =1          # from enum ErrorType3d
	et3dError10                   =10         # from enum ErrorType3d
	et3dError100                  =100        # from enum ErrorType3d
	et3dError101                  =101        # from enum ErrorType3d
	et3dError102                  =102        # from enum ErrorType3d
	et3dError103                  =103        # from enum ErrorType3d
	et3dError104                  =104        # from enum ErrorType3d
	et3dError105                  =105        # from enum ErrorType3d
	et3dError106                  =106        # from enum ErrorType3d
	et3dError107                  =107        # from enum ErrorType3d
	et3dError108                  =108        # from enum ErrorType3d
	et3dError109                  =109        # from enum ErrorType3d
	et3dError11                   =11         # from enum ErrorType3d
	et3dError110                  =110        # from enum ErrorType3d
	et3dError111                  =111        # from enum ErrorType3d
	et3dError112                  =112        # from enum ErrorType3d
	et3dError113                  =113        # from enum ErrorType3d
	et3dError114                  =114        # from enum ErrorType3d
	et3dError115                  =115        # from enum ErrorType3d
	et3dError116                  =116        # from enum ErrorType3d
	et3dError117                  =117        # from enum ErrorType3d
	et3dError118                  =118        # from enum ErrorType3d
	et3dError119                  =119        # from enum ErrorType3d
	et3dError12                   =12         # from enum ErrorType3d
	et3dError120                  =120        # from enum ErrorType3d
	et3dError121                  =121        # from enum ErrorType3d
	et3dError122                  =122        # from enum ErrorType3d
	et3dError123                  =123        # from enum ErrorType3d
	et3dError124                  =124        # from enum ErrorType3d
	et3dError125                  =125        # from enum ErrorType3d
	et3dError126                  =126        # from enum ErrorType3d
	et3dError127                  =127        # from enum ErrorType3d
	et3dError128                  =128        # from enum ErrorType3d
	et3dError129                  =129        # from enum ErrorType3d
	et3dError13                   =13         # from enum ErrorType3d
	et3dError130                  =130        # from enum ErrorType3d
	et3dError131                  =131        # from enum ErrorType3d
	et3dError132                  =132        # from enum ErrorType3d
	et3dError133                  =133        # from enum ErrorType3d
	et3dError134                  =134        # from enum ErrorType3d
	et3dError135                  =135        # from enum ErrorType3d
	et3dError136                  =136        # from enum ErrorType3d
	et3dError137                  =137        # from enum ErrorType3d
	et3dError138                  =138        # from enum ErrorType3d
	et3dError139                  =139        # from enum ErrorType3d
	et3dError14                   =14         # from enum ErrorType3d
	et3dError140                  =140        # from enum ErrorType3d
	et3dError141                  =141        # from enum ErrorType3d
	et3dError142                  =142        # from enum ErrorType3d
	et3dError143                  =143        # from enum ErrorType3d
	et3dError144                  =144        # from enum ErrorType3d
	et3dError145                  =145        # from enum ErrorType3d
	et3dError146                  =146        # from enum ErrorType3d
	et3dError147                  =147        # from enum ErrorType3d
	et3dError148                  =148        # from enum ErrorType3d
	et3dError149                  =149        # from enum ErrorType3d
	et3dError15                   =15         # from enum ErrorType3d
	et3dError150                  =150        # from enum ErrorType3d
	et3dError151                  =151        # from enum ErrorType3d
	et3dError152                  =152        # from enum ErrorType3d
	et3dError153                  =153        # from enum ErrorType3d
	et3dError154                  =154        # from enum ErrorType3d
	et3dError155                  =155        # from enum ErrorType3d
	et3dError156                  =156        # from enum ErrorType3d
	et3dError157                  =157        # from enum ErrorType3d
	et3dError158                  =158        # from enum ErrorType3d
	et3dError159                  =159        # from enum ErrorType3d
	et3dError16                   =16         # from enum ErrorType3d
	et3dError160                  =160        # from enum ErrorType3d
	et3dError161                  =161        # from enum ErrorType3d
	et3dError162                  =162        # from enum ErrorType3d
	et3dError163                  =163        # from enum ErrorType3d
	et3dError164                  =164        # from enum ErrorType3d
	et3dError165                  =165        # from enum ErrorType3d
	et3dError166                  =166        # from enum ErrorType3d
	et3dError167                  =167        # from enum ErrorType3d
	et3dError168                  =168        # from enum ErrorType3d
	et3dError169                  =169        # from enum ErrorType3d
	et3dError17                   =17         # from enum ErrorType3d
	et3dError170                  =170        # from enum ErrorType3d
	et3dError171                  =171        # from enum ErrorType3d
	et3dError172                  =172        # from enum ErrorType3d
	et3dError173                  =173        # from enum ErrorType3d
	et3dError174                  =174        # from enum ErrorType3d
	et3dError175                  =175        # from enum ErrorType3d
	et3dError176                  =176        # from enum ErrorType3d
	et3dError177                  =177        # from enum ErrorType3d
	et3dError179                  =179        # from enum ErrorType3d
	et3dError18                   =18         # from enum ErrorType3d
	et3dError180                  =180        # from enum ErrorType3d
	et3dError181                  =181        # from enum ErrorType3d
	et3dError182                  =182        # from enum ErrorType3d
	et3dError183                  =183        # from enum ErrorType3d
	et3dError184                  =184        # from enum ErrorType3d
	et3dError185                  =185        # from enum ErrorType3d
	et3dError186                  =186        # from enum ErrorType3d
	et3dError187                  =187        # from enum ErrorType3d
	et3dError188                  =188        # from enum ErrorType3d
	et3dError189                  =189        # from enum ErrorType3d
	et3dError19                   =19         # from enum ErrorType3d
	et3dError190                  =190        # from enum ErrorType3d
	et3dError191                  =191        # from enum ErrorType3d
	et3dError192                  =192        # from enum ErrorType3d
	et3dError193                  =193        # from enum ErrorType3d
	et3dError194                  =194        # from enum ErrorType3d
	et3dError195                  =195        # from enum ErrorType3d
	et3dError196                  =196        # from enum ErrorType3d
	et3dError197                  =197        # from enum ErrorType3d
	et3dError2                    =2          # from enum ErrorType3d
	et3dError20                   =20         # from enum ErrorType3d
	et3dError21                   =21         # from enum ErrorType3d
	et3dError22                   =22         # from enum ErrorType3d
	et3dError23                   =23         # from enum ErrorType3d
	et3dError24                   =24         # from enum ErrorType3d
	et3dError25                   =25         # from enum ErrorType3d
	et3dError26                   =26         # from enum ErrorType3d
	et3dError27                   =27         # from enum ErrorType3d
	et3dError28                   =28         # from enum ErrorType3d
	et3dError29                   =29         # from enum ErrorType3d
	et3dError3                    =3          # from enum ErrorType3d
	et3dError30                   =30         # from enum ErrorType3d
	et3dError31                   =31         # from enum ErrorType3d
	et3dError32                   =32         # from enum ErrorType3d
	et3dError33                   =33         # from enum ErrorType3d
	et3dError34                   =34         # from enum ErrorType3d
	et3dError35                   =35         # from enum ErrorType3d
	et3dError36                   =36         # from enum ErrorType3d
	et3dError37                   =37         # from enum ErrorType3d
	et3dError38                   =38         # from enum ErrorType3d
	et3dError39                   =39         # from enum ErrorType3d
	et3dError4                    =4          # from enum ErrorType3d
	et3dError40                   =40         # from enum ErrorType3d
	et3dError41                   =41         # from enum ErrorType3d
	et3dError42                   =42         # from enum ErrorType3d
	et3dError43                   =43         # from enum ErrorType3d
	et3dError44                   =44         # from enum ErrorType3d
	et3dError45                   =45         # from enum ErrorType3d
	et3dError46                   =46         # from enum ErrorType3d
	et3dError47                   =47         # from enum ErrorType3d
	et3dError48                   =48         # from enum ErrorType3d
	et3dError49                   =49         # from enum ErrorType3d
	et3dError5                    =5          # from enum ErrorType3d
	et3dError50                   =50         # from enum ErrorType3d
	et3dError51                   =51         # from enum ErrorType3d
	et3dError52                   =52         # from enum ErrorType3d
	et3dError53                   =53         # from enum ErrorType3d
	et3dError54                   =54         # from enum ErrorType3d
	et3dError55                   =55         # from enum ErrorType3d
	et3dError56                   =56         # from enum ErrorType3d
	et3dError57                   =57         # from enum ErrorType3d
	et3dError58                   =58         # from enum ErrorType3d
	et3dError59                   =59         # from enum ErrorType3d
	et3dError6                    =6          # from enum ErrorType3d
	et3dError60                   =60         # from enum ErrorType3d
	et3dError61                   =61         # from enum ErrorType3d
	et3dError62                   =62         # from enum ErrorType3d
	et3dError63                   =63         # from enum ErrorType3d
	et3dError64                   =64         # from enum ErrorType3d
	et3dError65                   =65         # from enum ErrorType3d
	et3dError66                   =66         # from enum ErrorType3d
	et3dError67                   =67         # from enum ErrorType3d
	et3dError68                   =68         # from enum ErrorType3d
	et3dError69                   =69         # from enum ErrorType3d
	et3dError7                    =7          # from enum ErrorType3d
	et3dError70                   =70         # from enum ErrorType3d
	et3dError71                   =71         # from enum ErrorType3d
	et3dError72                   =72         # from enum ErrorType3d
	et3dError73                   =73         # from enum ErrorType3d
	et3dError74                   =74         # from enum ErrorType3d
	et3dError75                   =75         # from enum ErrorType3d
	et3dError76                   =76         # from enum ErrorType3d
	et3dError77                   =77         # from enum ErrorType3d
	et3dError78                   =78         # from enum ErrorType3d
	et3dError79                   =79         # from enum ErrorType3d
	et3dError8                    =8          # from enum ErrorType3d
	et3dError80                   =80         # from enum ErrorType3d
	et3dError81                   =81         # from enum ErrorType3d
	et3dError82                   =82         # from enum ErrorType3d
	et3dError83                   =83         # from enum ErrorType3d
	et3dError84                   =84         # from enum ErrorType3d
	et3dError85                   =85         # from enum ErrorType3d
	et3dError86                   =86         # from enum ErrorType3d
	et3dError87                   =87         # from enum ErrorType3d
	et3dError88                   =88         # from enum ErrorType3d
	et3dError89                   =89         # from enum ErrorType3d
	et3dError9                    =9          # from enum ErrorType3d
	et3dError90                   =90         # from enum ErrorType3d
	et3dError91                   =91         # from enum ErrorType3d
	et3dError92                   =92         # from enum ErrorType3d
	et3dError93                   =93         # from enum ErrorType3d
	et3dError94                   =94         # from enum ErrorType3d
	et3dError95                   =95         # from enum ErrorType3d
	et3dError96                   =96         # from enum ErrorType3d
	et3dError97                   =97         # from enum ErrorType3d
	et3dError98                   =98         # from enum ErrorType3d
	et3dError99                   =99         # from enum ErrorType3d
	et3dNo3dDocument              =-7         # from enum ErrorType3d
	itBody                        =4          # from enum Intersection_Type
	itTangentCurve                =2          # from enum Intersection_Type
	itTangentPoint                =1          # from enum Intersection_Type
	itTangentSurface              =3          # from enum Intersection_Type
	mc_Angle                      =6          # from enum MateConstraintType
	mc_CamGear                    =10         # from enum MateConstraintType
	mc_Coincidence                =0          # from enum MateConstraintType
	mc_Concentric                 =4          # from enum MateConstraintType
	mc_Dependent                  =14         # from enum MateConstraintType
	mc_Distance                   =5          # from enum MateConstraintType
	mc_InPlace                    =7          # from enum MateConstraintType
	mc_Parallel                   =1          # from enum MateConstraintType
	mc_Perpendicular              =2          # from enum MateConstraintType
	mc_Symmetric                  =11         # from enum MateConstraintType
	mc_Tangency                   =3          # from enum MateConstraintType
	mc_Transmission               =9          # from enum MateConstraintType
	mc_Unknown                    =-1         # from enum MateConstraintType
	o3d_AngularUnhistoriedDimension=598        # from enum Obj3dType
	o3d_Arc3D                     =519        # from enum Obj3dType
	o3d_ArcDimension3D            =629        # from enum Obj3dType
	o3d_AreaMeasure               =558        # from enum Obj3dType
	o3d_ArrayExemplar             =549        # from enum Obj3dType
	o3d_AuxCircularCopy           =505        # from enum Obj3dType
	o3d_AuxCurveCopy              =506        # from enum Obj3dType
	o3d_AuxGeomArrayExemplar      =550        # from enum Obj3dType
	o3d_AuxMeshCopy               =504        # from enum Obj3dType
	o3d_AuxMirrorOperation        =509        # from enum Obj3dType
	o3d_AuxPointDrivenPattern     =520        # from enum Obj3dType
	o3d_AuxTablePattern           =524        # from enum Obj3dType
	o3d_AxisFromPointByDirection  =559        # from enum Obj3dType
	o3d_Billet                    =571        # from enum Obj3dType
	o3d_BodiesCircularCopy        =529        # from enum Obj3dType
	o3d_BodiesCurveCopy           =530        # from enum Obj3dType
	o3d_BodiesMeshCopy            =528        # from enum Obj3dType
	o3d_BodiesPointDrivenPattern  =521        # from enum Obj3dType
	o3d_BodiesTablePattern        =525        # from enum Obj3dType
	o3d_BodyArrayExemplar         =551        # from enum Obj3dType
	o3d_BodyReposition            =569        # from enum Obj3dType
	o3d_CircularPatternAnyCopy    =592        # from enum Obj3dType
	o3d_CloudPointsSurface        =527        # from enum Obj3dType
	o3d_CollectionGeometry        =590        # from enum Obj3dType
	o3d_CollisionObject           =622        # from enum Obj3dType
	o3d_ConicSectionSurface       =635        # from enum Obj3dType
	o3d_ConnectCurve              =510        # from enum Obj3dType
	o3d_ConnectCurveObject        =511        # from enum Obj3dType
	o3d_ContinuityCheck           =624        # from enum Obj3dType
	o3d_Contour3D                 =568        # from enum Obj3dType
	o3d_CopyGeometry              =589        # from enum Obj3dType
	o3d_CurvatureCheckObject      =623        # from enum Obj3dType
	o3d_CurvatureGraph            =621        # from enum Obj3dType
	o3d_Curve3DWithoutHistory     =560        # from enum Obj3dType
	o3d_CurveBy2Projections       =561        # from enum Obj3dType
	o3d_CurveByLaw                =562        # from enum Obj3dType
	o3d_CurveOutLine              =564        # from enum Obj3dType
	o3d_CurvePatternAnyCopy       =593        # from enum Obj3dType
	o3d_DiametralUnhistoriedDimension=600        # from enum Obj3dType
	o3d_DistanceAngleMeasure      =556        # from enum Obj3dType
	o3d_DynamicCrossSection       =619        # from enum Obj3dType
	o3d_EdgeLengthMeasure         =557        # from enum Obj3dType
	o3d_Embodiment                =164        # from enum Obj3dType
	o3d_Equidistant3D             =501        # from enum Obj3dType
	o3d_EquidistantSurface        =514        # from enum Obj3dType
	o3d_EvolutionSurface          =59         # from enum Obj3dType
	o3d_ExtensionSurface          =517        # from enum Obj3dType
	o3d_ExtrusionSurface          =60         # from enum Obj3dType
	o3d_FaceLift                  =601        # from enum Obj3dType
	o3d_FaceMover                 =632        # from enum Obj3dType
	o3d_FaceRemover               =95         # from enum Obj3dType
	o3d_FilletCurve               =512        # from enum Obj3dType
	o3d_FilletCurveObject         =513        # from enum Obj3dType
	o3d_FullFillet                =618        # from enum Obj3dType
	o3d_Hole3D                    =583        # from enum Obj3dType
	o3d_IsoparametricCurve        =563        # from enum Obj3dType
	o3d_IsoparametricCurvesSet    =566        # from enum Obj3dType
	o3d_JointSurface              =555        # from enum Obj3dType
	o3d_LineSegment3D             =570        # from enum Obj3dType
	o3d_LinearUnhistoriedDimension=597        # from enum Obj3dType
	o3d_LoftSurface               =62         # from enum Obj3dType
	o3d_MacroObject               =63         # from enum Obj3dType
	o3d_MeshObject3D              =613        # from enum Obj3dType
	o3d_MeshPatternAnyCopy        =591        # from enum Obj3dType
	o3d_MeshPointsSurface         =526        # from enum Obj3dType
	o3d_MirrorPart                =532        # from enum Obj3dType
	o3d_MoldCavity                =65         # from enum Obj3dType
	o3d_NurbsSurface              =97         # from enum Obj3dType
	o3d_NurbsSurfaceByCurvesMesh  =552        # from enum Obj3dType
	o3d_ObjectsFilter3D           =155        # from enum Obj3dType
	o3d_OperationAngularDimension =574        # from enum Obj3dType
	o3d_OperationDiametralDimension=576        # from enum Obj3dType
	o3d_OperationLeaderDimension  =617        # from enum Obj3dType
	o3d_OperationLinearDimension  =573        # from enum Obj3dType
	o3d_OperationRadialDimension  =575        # from enum Obj3dType
	o3d_PartsPointDrivenPattern   =508        # from enum Obj3dType
	o3d_PartsTablePattern         =523        # from enum Obj3dType
	o3d_PlaneByPlaneCurve         =554        # from enum Obj3dType
	o3d_PlaneByPointAndTangentToFace=553        # from enum Obj3dType
	o3d_PointDrivenPattern        =507        # from enum Obj3dType
	o3d_PointDrivenPatternAnyCopy =595        # from enum Obj3dType
	o3d_PointsArrFromFile         =547        # from enum Obj3dType
	o3d_PointsArrOnCurve          =546        # from enum Obj3dType
	o3d_PointsArrOnSurface        =548        # from enum Obj3dType
	o3d_PolyLine3DPoint           =572        # from enum Obj3dType
	o3d_PolygonalLineVertexParam  =158        # from enum Obj3dType
	o3d_ProjectionCurve           =567        # from enum Obj3dType
	o3d_RadialUnhistoriedDimension=599        # from enum Obj3dType
	o3d_RestoredSurface           =620        # from enum Obj3dType
	o3d_RotatedSurface            =61         # from enum Obj3dType
	o3d_RuledSurface              =515        # from enum Obj3dType
	o3d_Scaling3D                 =531        # from enum Obj3dType
	o3d_SectionAnalysis           =626        # from enum Obj3dType
	o3d_SketchAngularDimension    =578        # from enum Obj3dType
	o3d_SketchArcDimension        =628        # from enum Obj3dType
	o3d_SketchBreakAngularDimension=579        # from enum Obj3dType
	o3d_SketchBreakLinearDimension=605        # from enum Obj3dType
	o3d_SketchBreakRadialDimension=581        # from enum Obj3dType
	o3d_SketchDiametralDimension  =582        # from enum Obj3dType
	o3d_SketchFace                =625        # from enum Obj3dType
	o3d_SketchLinearDimension     =577        # from enum Obj3dType
	o3d_SketchRadialDimension     =580        # from enum Obj3dType
	o3d_SpecRough3D               =604        # from enum Obj3dType
	o3d_SplineFormOperation       =608        # from enum Obj3dType
	o3d_SplineOnSurface           =565        # from enum Obj3dType
	o3d_SplitLine                 =93         # from enum Obj3dType
	o3d_SplitSolid                =633        # from enum Obj3dType
	o3d_SubFoldLine               =616        # from enum Obj3dType
	o3d_SurfacePatch              =94         # from enum Obj3dType
	o3d_SurfaceSewer              =96         # from enum Obj3dType
	o3d_SurfaceThickening         =518        # from enum Obj3dType
	o3d_SurfacesIntersectionCurve =98         # from enum Obj3dType
	o3d_TablePattern              =522        # from enum Obj3dType
	o3d_TablePatternAnyCopy       =596        # from enum Obj3dType
	o3d_Text3D                    =627        # from enum Obj3dType
	o3d_TrimmedCurve              =502        # from enum Obj3dType
	o3d_TrimmedCurveObject        =503        # from enum Obj3dType
	o3d_TrimmedSurface            =516        # from enum Obj3dType
	o3d_UnHistoried               =79         # from enum Obj3dType
	o3d_UndefPartObject           =603        # from enum Obj3dType
	o3d_UnhistoriedBase3D         =609        # from enum Obj3dType
	o3d_UnhistoriedThread         =610        # from enum Obj3dType
	o3d_UnionComponents           =64         # from enum Obj3dType
	o3d_UserDesignationCompObj    =611        # from enum Obj3dType
	o3d_UserDesignationObject3D   =607        # from enum Obj3dType
	o3d_UserFolder                =612        # from enum Obj3dType
	o3d_UserObjectOperation       =584        # from enum Obj3dType
	o3d_UserWireFrame3D           =602        # from enum Obj3dType
	o3d_WireFrame3D               =588        # from enum Obj3dType
	o3d_Zone3D                    =585        # from enum Obj3dType
	o3d_Zone3DDivision            =586        # from enum Obj3dType
	o3d_Zones3D                   =587        # from enum Obj3dType
	o3d_additionFormat            =113        # from enum Obj3dType
	o3d_aggregate                 =69         # from enum Obj3dType
	o3d_angleDimension3D          =84         # from enum Obj3dType
	o3d_arc3dParam                =147        # from enum Obj3dType
	o3d_attribute                 =151        # from enum Obj3dType
	o3d_attributeCollection       =152        # from enum Obj3dType
	o3d_axis2Planes               =9          # from enum Obj3dType
	o3d_axis2Points               =10         # from enum Obj3dType
	o3d_axis3D                    =615        # from enum Obj3dType
	o3d_axisConeFace              =11         # from enum Obj3dType
	o3d_axisEdge                  =12         # from enum Obj3dType
	o3d_axisOX                    =71         # from enum Obj3dType
	o3d_axisOY                    =72         # from enum Obj3dType
	o3d_axisOZ                    =73         # from enum Obj3dType
	o3d_axisOperation             =13         # from enum Obj3dType
	o3d_base3D                    =91         # from enum Obj3dType
	o3d_baseEvolution             =45         # from enum Obj3dType
	o3d_baseExtrusion             =24         # from enum Obj3dType
	o3d_baseLoft                  =30         # from enum Obj3dType
	o3d_baseRotated               =27         # from enum Obj3dType
	o3d_baselineDimension3D       =80         # from enum Obj3dType
	o3d_body                      =115        # from enum Obj3dType
	o3d_bodyCollection            =114        # from enum Obj3dType
	o3d_bossEvolution             =46         # from enum Obj3dType
	o3d_bossExtrusion             =25         # from enum Obj3dType
	o3d_bossLoft                  =31         # from enum Obj3dType
	o3d_bossRotated               =28         # from enum Obj3dType
	o3d_brandLeader3D             =90         # from enum Obj3dType
	o3d_chamfer                   =33         # from enum Obj3dType
	o3d_chooseMng                 =146        # from enum Obj3dType
	o3d_circPartArray             =38         # from enum Obj3dType
	o3d_circle3dParam             =130        # from enum Obj3dType
	o3d_circularCopy              =36         # from enum Obj3dType
	o3d_componentPositioner       =153        # from enum Obj3dType
	o3d_coneParam                 =138        # from enum Obj3dType
	o3d_conicSpiral               =54         # from enum Obj3dType
	o3d_conjunctivePoint          =68         # from enum Obj3dType
	o3d_constrElement             =109        # from enum Obj3dType
	o3d_controlPoint              =67         # from enum Obj3dType
	o3d_coordinate3dCollection    =156        # from enum Obj3dType
	o3d_copyleftObject            =163        # from enum Obj3dType
	o3d_curve3D                   =126        # from enum Obj3dType
	o3d_curveCopy                 =37         # from enum Obj3dType
	o3d_curveElement              =111        # from enum Obj3dType
	o3d_curvePartArray            =40         # from enum Obj3dType
	o3d_cutByPlane                =50         # from enum Obj3dType
	o3d_cutBySketch               =51         # from enum Obj3dType
	o3d_cutEvolution              =47         # from enum Obj3dType
	o3d_cutExtrusion              =26         # from enum Obj3dType
	o3d_cutLoft                   =32         # from enum Obj3dType
	o3d_cutRotated                =29         # from enum Obj3dType
	o3d_cylinderParam             =139        # from enum Obj3dType
	o3d_cylindricSpiral           =56         # from enum Obj3dType
	o3d_deletedCopyCollection     =148        # from enum Obj3dType
	o3d_derivPartArray            =41         # from enum Obj3dType
	o3d_designationElement        =162        # from enum Obj3dType
	o3d_diametralDimension3D      =83         # from enum Obj3dType
	o3d_document                  =103        # from enum Obj3dType
	o3d_edge                      =7          # from enum Obj3dType
	o3d_edgeCollection            =121        # from enum Obj3dType
	o3d_ellipse3dParam            =131        # from enum Obj3dType
	o3d_entity                    =105        # from enum Obj3dType
	o3d_entityCollection          =102        # from enum Obj3dType
	o3d_face                      =6          # from enum Obj3dType
	o3d_faceCollection            =116        # from enum Obj3dType
	o3d_facet                     =118        # from enum Obj3dType
	o3d_feature                   =120        # from enum Obj3dType
	o3d_featureCollection         =119        # from enum Obj3dType
	o3d_fillet                    =34         # from enum Obj3dType
	o3d_firstEntityElement2       =500        # from enum Obj3dType
	o3d_holeOperation             =52         # from enum Obj3dType
	o3d_importedSurface           =57         # from enum Obj3dType
	o3d_incline                   =42         # from enum Obj3dType
	o3d_intersectionResult        =157        # from enum Obj3dType
	o3d_intervalVariable          =166        # from enum Obj3dType
	o3d_lastEntityElement         =99         # from enum Obj3dType
	o3d_lastEntityElement2        =1500       # from enum Obj3dType
	o3d_leader3D                  =86         # from enum Obj3dType
	o3d_lineDimension3D           =81         # from enum Obj3dType
	o3d_lineseg3dParam            =129        # from enum Obj3dType
	o3d_localCoordinateSystem     =85         # from enum Obj3dType
	o3d_loop                      =124        # from enum Obj3dType
	o3d_loopCollection            =125        # from enum Obj3dType
	o3d_markLeader3D              =87         # from enum Obj3dType
	o3d_massInertiaParam          =128        # from enum Obj3dType
	o3d_mateConstraint            =106        # from enum Obj3dType
	o3d_mateConstraintCollection  =107        # from enum Obj3dType
	o3d_mateConstraintGroup       =143        # from enum Obj3dType
	o3d_measurer                  =144        # from enum Obj3dType
	o3d_meshCopy                  =35         # from enum Obj3dType
	o3d_meshPartArray             =39         # from enum Obj3dType
	o3d_mirrorAllOperation        =49         # from enum Obj3dType
	o3d_mirrorOperation           =48         # from enum Obj3dType
	o3d_modelLibrary              =154        # from enum Obj3dType
	o3d_nurbs3dParam              =136        # from enum Obj3dType
	o3d_nurbsKnotCollection       =135        # from enum Obj3dType
	o3d_nurbsPoint3dCollCollection=134        # from enum Obj3dType
	o3d_nurbsPoint3dCollection    =133        # from enum Obj3dType
	o3d_nurbsPoint3dParam         =132        # from enum Obj3dType
	o3d_nurbsSurfaceParam         =142        # from enum Obj3dType
	o3d_operationElement          =110        # from enum Obj3dType
	o3d_orientedEdge              =122        # from enum Obj3dType
	o3d_orientedEdgeCollection    =123        # from enum Obj3dType
	o3d_part                      =104        # from enum Obj3dType
	o3d_partCollection            =108        # from enum Obj3dType
	o3d_placement                 =101        # from enum Obj3dType
	o3d_plane3Points              =16         # from enum Obj3dType
	o3d_planeAngle                =15         # from enum Obj3dType
	o3d_planeEdgePoint            =19         # from enum Obj3dType
	o3d_planeLineToEdge           =22         # from enum Obj3dType
	o3d_planeLineToPlane          =23         # from enum Obj3dType
	o3d_planeMiddle               =66         # from enum Obj3dType
	o3d_planeNormal               =17         # from enum Obj3dType
	o3d_planeOffset               =14         # from enum Obj3dType
	o3d_planeParallel             =20         # from enum Obj3dType
	o3d_planeParam                =137        # from enum Obj3dType
	o3d_planePerpendicular        =21         # from enum Obj3dType
	o3d_planeTangent              =18         # from enum Obj3dType
	o3d_planeXOY                  =1          # from enum Obj3dType
	o3d_planeXOZ                  =2          # from enum Obj3dType
	o3d_planeYOZ                  =3          # from enum Obj3dType
	o3d_point3D                   =70         # from enum Obj3dType
	o3d_pointCS                   =4          # from enum Obj3dType
	o3d_polyline                  =53         # from enum Obj3dType
	o3d_positionLeader3D          =89         # from enum Obj3dType
	o3d_radialDimension3D         =82         # from enum Obj3dType
	o3d_rasterFormat              =112        # from enum Obj3dType
	o3d_ribOperation              =44         # from enum Obj3dType
	o3d_rough3D                   =88         # from enum Obj3dType
	o3d_sTrackingPointsMeasurer   =160        # from enum Obj3dType
	o3d_selectionMng              =145        # from enum Obj3dType
	o3d_sheetMetalBeat            =543        # from enum Obj3dType
	o3d_sheetMetalBend            =75         # from enum Obj3dType
	o3d_sheetMetalBendBended      =537        # from enum Obj3dType
	o3d_sheetMetalBendObject      =540        # from enum Obj3dType
	o3d_sheetMetalBendStraighten  =536        # from enum Obj3dType
	o3d_sheetMetalBendUnfold      =538        # from enum Obj3dType
	o3d_sheetMetalBody            =74         # from enum Obj3dType
	o3d_sheetMetalClosedCorner    =539        # from enum Obj3dType
	o3d_sheetMetalCombinedBend    =535        # from enum Obj3dType
	o3d_sheetMetalConvertFromBody =634        # from enum Obj3dType
	o3d_sheetMetalCowling         =545        # from enum Obj3dType
	o3d_sheetMetalCut             =78         # from enum Obj3dType
	o3d_sheetMetalDimpleCutout    =541        # from enum Obj3dType
	o3d_sheetMetalDrawnCutout     =542        # from enum Obj3dType
	o3d_sheetMetalFlanging        =631        # from enum Obj3dType
	o3d_sheetMetalHole            =77         # from enum Obj3dType
	o3d_sheetMetalLineBend        =76         # from enum Obj3dType
	o3d_sheetMetalLinearCowling   =606        # from enum Obj3dType
	o3d_sheetMetalLouver          =544        # from enum Obj3dType
	o3d_sheetMetalPlate           =534        # from enum Obj3dType
	o3d_sheetMetalPunch           =630        # from enum Obj3dType
	o3d_sheetMetalRib             =614        # from enum Obj3dType
	o3d_sheetMetalUndercut        =533        # from enum Obj3dType
	o3d_shellOperation            =43         # from enum Obj3dType
	o3d_sketch                    =5          # from enum Obj3dType
	o3d_sphereParam               =140        # from enum Obj3dType
	o3d_spline                    =55         # from enum Obj3dType
	o3d_surface                   =127        # from enum Obj3dType
	o3d_surfaceElement            =161        # from enum Obj3dType
	o3d_tessellation              =117        # from enum Obj3dType
	o3d_thread                    =58         # from enum Obj3dType
	o3d_tolerance3D               =92         # from enum Obj3dType
	o3d_torusParam                =141        # from enum Obj3dType
	o3d_unknown                   =0          # from enum Obj3dType
	o3d_userFunc                  =167        # from enum Obj3dType
	o3d_userMateConstraint        =165        # from enum Obj3dType
	o3d_variable                  =100        # from enum Obj3dType
	o3d_variableCollection        =159        # from enum Obj3dType
	o3d_vertex                    =8          # from enum Obj3dType
	o3d_viewProjection            =149        # from enum Obj3dType
	o3d_viewProjectionCollection  =150        # from enum Obj3dType
	pEdit_Part                    =-2         # from enum Part_Type
	pInPlace_Part                 =-4         # from enum Part_Type
	pNew_Part                     =-3         # from enum Part_Type
	pTop_Part                     =-1         # from enum Part_Type
	pnMove                        =0          # from enum Positioner_Type
	pnRotate                      =1          # from enum Positioner_Type
	useColorLayer                 =3          # from enum UseColor
	useColorOur                   =0          # from enum UseColor
	useColorOwner                 =1          # from enum UseColor
	useColorSource                =2          # from enum UseColor
	useColorUnknown               =-1         # from enum UseColor
	vm_HiddenRemoved              =1          # from enum ViewMode
	vm_HiddenThin                 =2          # from enum ViewMode
	vm_Shaded                     =3          # from enum ViewMode
	vm_Wireframe                  =0          # from enum ViewMode
	ksCS3DDashDot                 =4          # from enum ks3DLineStyle
	ksCS3DDashDotLDash2Dots       =5          # from enum ks3DLineStyle
	ksCS3DDashed                  =2          # from enum ks3DLineStyle
	ksCS3DDotted                  =3          # from enum ks3DLineStyle
	ksCS3DNoDrawing               =0          # from enum ks3DLineStyle
	ksCS3DSolid                   =1          # from enum ks3DLineStyle
	ksArc3DByCentre               =1          # from enum ksArc3DBuildingTypeEnum
	ksArc3DByDirrection           =2          # from enum ksArc3DBuildingTypeEnum
	ksArc3DByPoints               =0          # from enum ksArc3DBuildingTypeEnum
	ksArc3DByTanCurve             =3          # from enum ksArc3DBuildingTypeEnum
	ksArc3DAngle1                 =1          # from enum ksArc3DParameterEnum
	ksArc3DAngle2                 =2          # from enum ksArc3DParameterEnum
	ksArc3DCenter                 =0          # from enum ksArc3DParameterEnum
	ksArc3DPoint1                 =1          # from enum ksArc3DParameterEnum
	ksArc3DPoint2                 =2          # from enum ksArc3DParameterEnum
	ksArc3DPoint3                 =3          # from enum ksArc3DParameterEnum
	ksArc3DRadius                 =3          # from enum ksArc3DParameterEnum
	ksArchMeasureByCoefficient    =0          # from enum ksArchMeasureEnum
	ksArchMeasureByLength         =1          # from enum ksArchMeasureEnum
	ksBinormalVector              =2          # from enum ksBasisVectorTypeEnum
	ksNormalVector                =1          # from enum ksBasisVectorTypeEnum
	ksTangentVector               =0          # from enum ksBasisVectorTypeEnum
	ksBendAngleAllBends           =2          # from enum ksBendAngleReleaseTypeEnum
	ksBendAngleBendOnly           =0          # from enum ksBendAngleReleaseTypeEnum
	ksBendAngleIn                 =1          # from enum ksBendAngleReleaseTypeEnum
	ksBendDisposalAllLength       =0          # from enum ksBendDisposalEnum
	ksBendDisposalCentre          =1          # from enum ksBendDisposalEnum
	ksBendDisposalLeft            =2          # from enum ksBendDisposalEnum
	ksBendDisposalLeftAndWidth    =5          # from enum ksBendDisposalEnum
	ksBendDisposalRight           =3          # from enum ksBendDisposalEnum
	ksBendDisposalRightAndWidth   =6          # from enum ksBendDisposalEnum
	ksBendDisposalTwo             =4          # from enum ksBendDisposalEnum
	ksBendLengthByContinue        =0          # from enum ksBendLengthTypeEnum
	ksBendLengthByContour         =1          # from enum ksBendLengthTypeEnum
	ksBendLengthByContourInternal =3          # from enum ksBendLengthTypeEnum
	ksBendLengthByTangentInternal =4          # from enum ksBendLengthTypeEnum
	ksBendLengthByTouch           =2          # from enum ksBendLengthTypeEnum
	ksBendOffsetByCentre          =5          # from enum ksBendOffsetTypeEnum
	ksBendOffsetByTouch           =4          # from enum ksBendOffsetTypeEnum
	ksBendOffsetIn                =0          # from enum ksBendOffsetTypeEnum
	ksBendOffsetLineInside        =3          # from enum ksBendOffsetTypeEnum
	ksBendOffsetLineOutside       =2          # from enum ksBendOffsetTypeEnum
	ksBendOffsetOut               =1          # from enum ksBendOffsetTypeEnum
	ksBendReleaseByCircle         =1          # from enum ksBendReleaseTypeEnum
	ksBendReleaseByRect           =0          # from enum ksBendReleaseTypeEnum
	ksBendSideByAngle             =0          # from enum ksBendSideTypeEnum
	ksBendSideByWidening          =1          # from enum ksBendSideTypeEnum
	ksBendByCentre                =4          # from enum ksBendTypeEnum
	ksBendByTouch                 =3          # from enum ksBendTypeEnum
	ksBendLineInside              =2          # from enum ksBendTypeEnum
	ksBendLineOutside             =1          # from enum ksBendTypeEnum
	ksLineBend                    =0          # from enum ksBendTypeEnum
	ksChamferSideAngle            =0          # from enum ksChamferBuildingTypeEnum
	ksChamferTwoSides             =1          # from enum ksChamferBuildingTypeEnum
	ksAllBodies                   =3          # from enum ksChooseBodiesType
	ksAutomaticDefinition         =1          # from enum ksChooseBodiesType
	ksManualEditing               =2          # from enum ksChooseBodiesType
	ksNewBody                     =0          # from enum ksChooseBodiesType
	ksChAllParts                  =3          # from enum ksChoosePartsType
	ksChAutomaticDefinition       =1          # from enum ksChoosePartsType
	ksChManualEditing             =2          # from enum ksChoosePartsType
	ksChNoLibraryParts            =4          # from enum ksChoosePartsType
	ksChBodies                    =3          # from enum ksChooseType
	ksChBodiesAndParts            =1          # from enum ksChooseType
	ksChParts                     =2          # from enum ksChooseType
	ksCPChessOrderByAxis1         =1          # from enum ksCircularPatternBuildingTypeEnum
	ksCPChessOrderByAxis2         =2          # from enum ksCircularPatternBuildingTypeEnum
	ksCPSaveAll                   =0          # from enum ksCircularPatternBuildingTypeEnum
	ksClosingCJoint               =0          # from enum ksClosingClosedTypeEnum
	ksClosingCOver                =1          # from enum ksClosingClosedTypeEnum
	ksClosingCTightClosure        =2          # from enum ksClosingClosedTypeEnum
	ksCorneringCircled            =3          # from enum ksClosingCorneringEnum
	ksCorneringJointOnBorder      =1          # from enum ksClosingCorneringEnum
	ksCorneringJointOnChord       =2          # from enum ksClosingCorneringEnum
	ksCorneringNone               =0          # from enum ksClosingCorneringEnum
	ksCorneringHPAngle            =1          # from enum ksClosingHolePlacementEnum
	ksCorneringHPBend             =0          # from enum ksClosingHolePlacementEnum
	ksCorneringHPPoint            =2          # from enum ksClosingHolePlacementEnum
	ksClosingAngles               =0          # from enum ksClosingTypeEnum
	ksClosingBegin                =1          # from enum ksClosingTypeEnum
	ksClosingEnd                  =2          # from enum ksClosingTypeEnum
	ksCLByPoints                  =0          # from enum ksCloudPointsSurfaceBuildingTypeEnum
	ksCLByPole                    =1          # from enum ksCloudPointsSurfaceBuildingTypeEnum
	ksCLPolyhedral                =2          # from enum ksCloudPointsSurfaceBuildingTypeEnum
	ksCLAuto                      =0          # from enum ksCloudTypeEnum
	ksCLLocalCS                   =1          # from enum ksCloudTypeEnum
	ksCLScreen                    =2          # from enum ksCloudTypeEnum
	ksCNAngle                     =1          # from enum ksConicTypeEnum
	ksCNDiameter                  =0          # from enum ksConicTypeEnum
	ksCPByObject                  =0          # from enum ksConjunctivePointTypeEnum
	ksCPManualDirection           =1          # from enum ksConjunctivePointTypeEnum
	ksCTNormal                    =2          # from enum ksConnectTypeEnum
	ksCTPosition                  =0          # from enum ksConnectTypeEnum
	ksCTSmooth                    =3          # from enum ksConnectTypeEnum
	ksCTTangent                   =1          # from enum ksConnectTypeEnum
	ksCTUnknown                   =-1         # from enum ksConnectTypeEnum
	ksCBTEdges                    =1          # from enum ksContour3DBuildingTypeTypeEnum
	ksCBTEquidistant              =2          # from enum ksContour3DBuildingTypeTypeEnum
	ksCBTUnknown                  =0          # from enum ksContour3DBuildingTypeTypeEnum
	ksCTAuto                      =0          # from enum ksContour3DTypeEnum
	ksCTSketch                    =3          # from enum ksContour3DTypeEnum
	ksCTSpace                     =1          # from enum ksContour3DTypeEnum
	ksCTSurface                   =2          # from enum ksContour3DTypeEnum
	ksCLawX                       =0          # from enum ksCoordLawEnum
	ksCLawY                       =1          # from enum ksCoordLawEnum
	ksCLawZ                       =2          # from enum ksCoordLawEnum
	ksCGBTBodyFaceGrouping        =1          # from enum ksCopyGeometryBuildingTypeEnum
	ksCGBTWithoutGrouping         =0          # from enum ksCopyGeometryBuildingTypeEnum
	ksCTDepthAngle                =1          # from enum ksCountersinkTypeEnum
	ksCTDiameterAngle             =0          # from enum ksCountersinkTypeEnum
	ksCTDiameterDepth             =2          # from enum ksCountersinkTypeEnum
	ksCrossSectionPlaneByModelPlane=0          # from enum ksCrossSectionPlaneBuildingTypeEnum
	ksCrossSectionPlaneByOtherStep=1          # from enum ksCrossSectionPlaneBuildingTypeEnum
	ksCPNearest                   =0          # from enum ksCurveProjectionTypeEnum
	ksCPNearestByDirection        =1          # from enum ksCurveProjectionTypeEnum
	ksCutByContour                =0          # from enum ksCutBuildingTypeEnum
	ksCutByPlane                  =1          # from enum ksCutBuildingTypeEnum
	ksD3CAssociated               =26         # from enum ksD3ConverterOptionsEnum
	ksD3CBRep                     =20         # from enum ksD3ConverterOptionsEnum
	ksD3COAttributes              =18         # from enum ksD3ConverterOptionsEnum
	ksD3COBodyes                  =0          # from enum ksD3ConverterOptionsEnum
	ksD3COCurves                  =4          # from enum ksD3ConverterOptionsEnum
	ksD3CODimensions              =16         # from enum ksD3ConverterOptionsEnum
	ksD3CODocumentProperties      =12         # from enum ksD3ConverterOptionsEnum
	ksD3COInvisibleObjects        =8          # from enum ksD3ConverterOptionsEnum
	ksD3COPoints                  =10         # from enum ksD3ConverterOptionsEnum
	ksD3COSketches                =6          # from enum ksD3ConverterOptionsEnum
	ksD3COStyle                   =28         # from enum ksD3ConverterOptionsEnum
	ksD3COSurfaces                =2          # from enum ksD3ConverterOptionsEnum
	ksD3COTechnicalDemand         =14         # from enum ksD3ConverterOptionsEnum
	ksD3CPolygonal                =22         # from enum ksD3ConverterOptionsEnum
	ksD3CPolygonalLOD0            =24         # from enum ksD3ConverterOptionsEnum
	ksDTObject                    =2          # from enum ksDepthTypeEnum
	ksDTReachThrough              =1          # from enum ksDepthTypeEnum
	ksDTValue                     =0          # from enum ksDepthTypeEnum
	ksDCSTByBorderPoints          =4          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByFreePlane             =0          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByOffsetPlane           =1          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByRotatedPlane          =2          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByZone                  =3          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTUnknown                 =-1         # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksECChooseObject1             =1          # from enum ksEditColorTypeEnum
	ksECChooseObject2             =2          # from enum ksEditColorTypeEnum
	ksECChooseObject3             =3          # from enum ksEditColorTypeEnum
	ksECDimensions                =7          # from enum ksEditColorTypeEnum
	ksECFacePhantom               =5          # from enum ksEditColorTypeEnum
	ksECLabelsPhantom             =6          # from enum ksEditColorTypeEnum
	ksECPassiveParts              =4          # from enum ksEditColorTypeEnum
	ksECSelectObject              =0          # from enum ksEditColorTypeEnum
	ksESByLayer                   =2          # from enum ksEditableStateEnum
	ksESDisable                   =0          # from enum ksEditableStateEnum
	ksESEnable                    =1          # from enum ksEditableStateEnum
	ksESUndefined                 =-1         # from enum ksEditableStateEnum
	ksEFConic                     =1          # from enum ksEndFaceTypeEnum
	ksEFFlat                      =0          # from enum ksEndFaceTypeEnum
	ksEFSphere                    =2          # from enum ksEndFaceTypeEnum
	ksECMCircle                   =2          # from enum ksEquidistant3DCutModeEnum
	ksECMLineSeg                  =1          # from enum ksEquidistant3DCutModeEnum
	ksECMUnknown                  =0          # from enum ksEquidistant3DCutModeEnum
	ksEvShiftKeepAngle            =1          # from enum ksEvolutionShiftSketchTypeEnum
	ksEvShiftOrtogonal            =2          # from enum ksEvolutionShiftSketchTypeEnum
	ksEvShiftParallel             =0          # from enum ksEvolutionShiftSketchTypeEnum
	ksETLUnknown                  =-1         # from enum ksExtensionLimitTypeEnum
	ksETLVertex                   =1          # from enum ksExtensionLimitTypeEnum
	ksETLength                    =0          # from enum ksExtensionLimitTypeEnum
	ksESTDirection                =2          # from enum ksExtensionSurfaceTypeEnum
	ksESTSelf                     =0          # from enum ksExtensionSurfaceTypeEnum
	ksESTTangent                  =1          # from enum ksExtensionSurfaceTypeEnum
	ksESTUnknown                  =-1         # from enum ksExtensionSurfaceTypeEnum
	ksFSMAll                      =3          # from enum ksFacetCullingMode
	ksFSMBack                     =2          # from enum ksFacetCullingMode
	ksFSMFront                    =1          # from enum ksFacetCullingMode
	ksFSMNone                     =0          # from enum ksFacetCullingMode
	ksFSBrokenLink                =2097152    # from enum ksFeatureStateEnum
	ksFSComprisedOfParts          =16         # from enum ksFeatureStateEnum
	ksFSCurrent                   =32         # from enum ksFeatureStateEnum
	ksFSDetailedFold              =128        # from enum ksFeatureStateEnum
	ksFSEditImpossible            =4096       # from enum ksFeatureStateEnum
	ksFSEditRestricted            =2048       # from enum ksFeatureStateEnum
	ksFSFixedComponent            =8192       # from enum ksFeatureStateEnum
	ksFSInside3dMacro             =4          # from enum ksFeatureStateEnum
	ksFSLCSDependent              =8          # from enum ksFeatureStateEnum
	ksFSLocked                    =1          # from enum ksFeatureStateEnum
	ksFSNone                      =0          # from enum ksFeatureStateEnum
	ksFSPutInRecalcState          =16384      # from enum ksFeatureStateEnum
	ksFSReadOnlyAccessA3d         =32768      # from enum ksFeatureStateEnum
	ksFSReadOnlyAccessM3d         =64         # from enum ksFeatureStateEnum
	ksFSRebuild                   =2          # from enum ksFeatureStateEnum
	ksFSSketchDefined             =512        # from enum ksFeatureStateEnum
	ksFSSketchRedefined           =1024       # from enum ksFeatureStateEnum
	ksFSSketchUndefined           =256        # from enum ksFeatureStateEnum
	ksFSUncuttable                =65536      # from enum ksFeatureStateEnum
	ksFSUpdateNeeded              =1048576    # from enum ksFeatureStateEnum
	ksFilletCircleArc             =0          # from enum ksFilletBuildingTypeEnum
	ksFilletCoefficient           =2          # from enum ksFilletBuildingTypeEnum
	ksFilletEllipseArc            =1          # from enum ksFilletBuildingTypeEnum
	ksFilletHord                  =3          # from enum ksFilletBuildingTypeEnum
	ksFilletOffsetByAngle         =2          # from enum ksFilletOffsetModeEnum
	ksFilletOffsetByLength        =1          # from enum ksFilletOffsetModeEnum
	ksFilletOffsetByPersent       =0          # from enum ksFilletOffsetModeEnum
	ksGabaritByBorderPoints       =0          # from enum ksGabaritBuildingTypeEnum
	ksGabaritByCenterAndBorder    =1          # from enum ksGabaritBuildingTypeEnum
	ksHoleCutByDepth              =1          # from enum ksHoleCutTypeEnum
	ksHoleCutByWidth              =0          # from enum ksHoleCutTypeEnum
	ksHoleCutUpToSurface          =2          # from enum ksHoleCutTypeEnum
	ksHTBase                      =0          # from enum ksHoleTypeEnum
	ksHTConic                     =4          # from enum ksHoleTypeEnum
	ksHTCounterbore               =1          # from enum ksHoleTypeEnum
	ksHTCounterdrill              =3          # from enum ksHoleTypeEnum
	ksHTCountersinking            =2          # from enum ksHoleTypeEnum
	ksHTLfrLibrary                =5          # from enum ksHoleTypeEnum
	ksJalousieExtract             =0          # from enum ksJalousieBuildingTypeEnum
	ksJalousieTrim                =1          # from enum ksJalousieBuildingTypeEnum
	ksJalousieNormal              =1          # from enum ksJalousieFormEndEnum
	ksJalousieTangent             =0          # from enum ksJalousieFormEndEnum
	ksJalousieAllHeight           =0          # from enum ksJalousieHeightTypeEnum
	ksJalousieSlotHeight          =2          # from enum ksJalousieHeightTypeEnum
	ksJalousieUpToFaceHeight      =1          # from enum ksJalousieHeightTypeEnum
	ksTLawByExpression            =3          # from enum ksLawTypeEnum
	ksTLawConst                   =0          # from enum ksLawTypeEnum
	ksTLawCube                    =2          # from enum ksLawTypeEnum
	ksTLawLinear                  =1          # from enum ksLawTypeEnum
	ksLBDistance                  =0          # from enum ksLengthBuildingTypeEnum
	ksLBToSurface                 =3          # from enum ksLengthBuildingTypeEnum
	ksLBToVertex                  =2          # from enum ksLengthBuildingTypeEnum
	ksLBTByPoint                  =0          # from enum ksLineBuildingType
	ksLBTByPoint3DParams          =6          # from enum ksLineBuildingType
	ksLBTParallel                 =4          # from enum ksLineBuildingType
	ksLBTPerpendicular            =5          # from enum ksLineBuildingType
	ksLBTXDirection               =1          # from enum ksLineBuildingType
	ksLBTYDirection               =2          # from enum ksLineBuildingType
	ksLBTZDirection               =3          # from enum ksLineBuildingType
	ksLSTPointLenghtAngle         =1          # from enum ksLineSegment3DTypeEnum
	ksLSTTwoPoints                =0          # from enum ksLineSegment3DTypeEnum
	ksLPChessOrderByAxis1         =3          # from enum ksLinearPatternBuildingTypeEnum
	ksLPChessOrderByAxis2         =4          # from enum ksLinearPatternBuildingTypeEnum
	ksLPSaveAll                   =0          # from enum ksLinearPatternBuildingTypeEnum
	ksLPSaveAlongAxially          =2          # from enum ksLinearPatternBuildingTypeEnum
	ksLPSaveAlongPerimeter        =1          # from enum ksLinearPatternBuildingTypeEnum
	ksLCompletely                 =0          # from enum ksLoadStateEnum
	ksLGabarit                    =4          # from enum ksLoadStateEnum
	ksLPartially                  =3          # from enum ksLoadStateEnum
	ksLTriangles                  =2          # from enum ksLoadStateEnum
	ksLUnknown                    =-1         # from enum ksLoadStateEnum
	ksLUnload                     =1          # from enum ksLoadStateEnum
	ksLoftAuto                    =0          # from enum ksLoftBuildingType
	ksLoftByNormal                =1          # from enum ksLoftBuildingType
	ksLoftByObject                =2          # from enum ksLoftBuildingType
	ksLoftCupola                  =3          # from enum ksLoftBuildingType
	ksManipulatorModeDefault      =1          # from enum ksManipulatorModeEnum
	ksManipulatorModeNotHandleEditor=2          # from enum ksManipulatorModeEnum
	ksMPAxisX                     =1          # from enum ksManipulatorPrimitiveEnum
	ksMPAxisY                     =2          # from enum ksManipulatorPrimitiveEnum
	ksMPAxisZ                     =3          # from enum ksManipulatorPrimitiveEnum
	ksMPConturXY                  =7          # from enum ksManipulatorPrimitiveEnum
	ksMPConturXZ                  =8          # from enum ksManipulatorPrimitiveEnum
	ksMPConturYZ                  =9          # from enum ksManipulatorPrimitiveEnum
	ksMPNone                      =0          # from enum ksManipulatorPrimitiveEnum
	ksMPOriginal                  =13         # from enum ksManipulatorPrimitiveEnum
	ksMPPlaceXOY                  =4          # from enum ksManipulatorPrimitiveEnum
	ksMPPlaceXOZ                  =5          # from enum ksManipulatorPrimitiveEnum
	ksMPPlaceYOZ                  =6          # from enum ksManipulatorPrimitiveEnum
	ksMPTextX                     =10         # from enum ksManipulatorPrimitiveEnum
	ksMPTextY                     =11         # from enum ksManipulatorPrimitiveEnum
	ksMPTextZ                     =12         # from enum ksManipulatorPrimitiveEnum
	ksEditDoubleManipulator       =2          # from enum ksManipulatorTypeEnum
	ksPlacement3DManipulator      =1          # from enum ksManipulatorTypeEnum
	ksMCAlignmentClosest          =0          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignmentCooriented       =1          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignmentOpposite         =-1         # from enum ksMateConstraintAlignmentEnum
	ksMCAlignmentUnknown          =2          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignment_1               =3          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignment_2               =4          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignment_3               =5          # from enum ksMateConstraintAlignmentEnum
	ksMCReverse_1                 =6          # from enum ksMateConstraintAlignmentEnum
	ksMCReverse_2                 =7          # from enum ksMateConstraintAlignmentEnum
	ksMCReverse_3                 =8          # from enum ksMateConstraintAlignmentEnum
	ksMFixedPart1                 =1          # from enum ksMateFixedTypeEnum
	ksMFixedPart2                 =2          # from enum ksMateFixedTypeEnum
	ksMFixedUnknown               =0          # from enum ksMateFixedTypeEnum
	ksMMotionLinear               =1          # from enum ksMateMotionTypeEnum
	ksMMotionRotation             =2          # from enum ksMateMotionTypeEnum
	ksMMotionUnknown              =0          # from enum ksMateMotionTypeEnum
	ksMTangentByCircle            =3          # from enum ksMateTangentTypeEnum
	ksMTangentByGeneratrixLine    =2          # from enum ksMateTangentTypeEnum
	ksMTangentByPoint             =1          # from enum ksMateTangentTypeEnum
	ksMTangentUnknown             =0          # from enum ksMateTangentTypeEnum
	ksMateCircle                  =8          # from enum ksMateType
	ksMateCone                    =5          # from enum ksMateType
	ksMateCylinder                =4          # from enum ksMateType
	ksMateLine                    =2          # from enum ksMateType
	ksMatePlane                   =3          # from enum ksMateType
	ksMatePoint                   =1          # from enum ksMateType
	ksMateSphere                  =6          # from enum ksMateType
	ksMateTorus                   =7          # from enum ksMateType
	ksMateUnknown                 =0          # from enum ksMateType
	ks3DCurve                     =0          # from enum ksMathCurve3DTypeEnum
	ksArc3D                       =3          # from enum ksMathCurve3DTypeEnum
	ksBSpline                     =25         # from enum ksMathCurve3DTypeEnum
	ksBezier3D                    =11         # from enum ksMathCurve3DTypeEnum
	ksBridgeCurve3D               =18         # from enum ksMathCurve3DTypeEnum
	ksCharacterCurve3D            =19         # from enum ksMathCurve3DTypeEnum
	ksConeSpiral                  =5          # from enum ksMathCurve3DTypeEnum
	ksContour3D                   =26         # from enum ksMathCurve3DTypeEnum
	ksContourOnPlane              =21         # from enum ksMathCurve3DTypeEnum
	ksContourOnSurface            =20         # from enum ksMathCurve3DTypeEnum
	ksCrookedSpiral               =7          # from enum ksMathCurve3DTypeEnum
	ksCubicSpline3D               =13         # from enum ksMathCurve3DTypeEnum
	ksCurveSpiral                 =6          # from enum ksMathCurve3DTypeEnum
	ksHermit3D                    =12         # from enum ksMathCurve3DTypeEnum
	ksLine3D                      =1          # from enum ksMathCurve3DTypeEnum
	ksLineSegment3D               =2          # from enum ksMathCurve3DTypeEnum
	ksNurbs3D                     =10         # from enum ksMathCurve3DTypeEnum
	ksOffsetCurve3D               =15         # from enum ksMathCurve3DTypeEnum
	ksPlaneCurve                  =14         # from enum ksMathCurve3DTypeEnum
	ksPolyCurve3D                 =8          # from enum ksMathCurve3DTypeEnum
	ksPolyline3D                  =9          # from enum ksMathCurve3DTypeEnum
	ksReparamCurve3D              =17         # from enum ksMathCurve3DTypeEnum
	ksSilhouetteCurve             =23         # from enum ksMathCurve3DTypeEnum
	ksSpiral                      =4          # from enum ksMathCurve3DTypeEnum
	ksSurfaceCurve                =22         # from enum ksMathCurve3DTypeEnum
	ksSurfaceIntersectionCurve    =24         # from enum ksMathCurve3DTypeEnum
	ksTrimmedCurve3D              =16         # from enum ksMathCurve3DTypeEnum
	ks3DSurface                   =0          # from enum ksMathSurface3DTypeEnum
	ksBendedUnbendedSurface       =37         # from enum ksMathSurface3DTypeEnum
	ksChamferSurface              =32         # from enum ksMathSurface3DTypeEnum
	ksChannelSurface              =34         # from enum ksMathSurface3DTypeEnum
	ksConeSurface                 =3          # from enum ksMathSurface3DTypeEnum
	ksConicBendedSurface          =40         # from enum ksMathSurface3DTypeEnum
	ksConicUnbendedSurface        =41         # from enum ksMathSurface3DTypeEnum
	ksCoonsPatchSurface           =28         # from enum ksMathSurface3DTypeEnum
	ksCornerSurface               =26         # from enum ksMathSurface3DTypeEnum
	ksCoverSurface                =27         # from enum ksMathSurface3DTypeEnum
	ksCurveBoundedSurface         =36         # from enum ksMathSurface3DTypeEnum
	ksCylinderSurface             =4          # from enum ksMathSurface3DTypeEnum
	ksCylindricBendedSurface      =38         # from enum ksMathSurface3DTypeEnum
	ksCylindricUnbendedSurface    =39         # from enum ksMathSurface3DTypeEnum
	ksDeformedSurface             =24         # from enum ksMathSurface3DTypeEnum
	ksElementarySurface           =1          # from enum ksMathSurface3DTypeEnum
	ksElevationSurface            =13         # from enum ksMathSurface3DTypeEnum
	ksEvolutionSurface            =10         # from enum ksMathSurface3DTypeEnum
	ksExactionSurface             =11         # from enum ksMathSurface3DTypeEnum
	ksExpansionSurface            =12         # from enum ksMathSurface3DTypeEnum
	ksExplorationSurface          =42         # from enum ksMathSurface3DTypeEnum
	ksExtrusionSurface            =8          # from enum ksMathSurface3DTypeEnum
	ksFilletSurface               =33         # from enum ksMathSurface3DTypeEnum
	ksFreeSurface                 =200        # from enum ksMathSurface3DTypeEnum
	ksGridSurface                 =20         # from enum ksMathSurface3DTypeEnum
	ksHermitSurface               =18         # from enum ksMathSurface3DTypeEnum
	ksJoinSurface                 =35         # from enum ksMathSurface3DTypeEnum
	ksLoftedSurface               =30         # from enum ksMathSurface3DTypeEnum
	ksMeshSurface                 =29         # from enum ksMathSurface3DTypeEnum
	ksNurbsSurface                =25         # from enum ksMathSurface3DTypeEnum
	ksOffsetSurface               =23         # from enum ksMathSurface3DTypeEnum
	ksPlane                       =2          # from enum ksMathSurface3DTypeEnum
	ksPolySurface                 =17         # from enum ksMathSurface3DTypeEnum
	ksRevolutionSurface           =9          # from enum ksMathSurface3DTypeEnum
	ksRuledSurface                =15         # from enum ksMathSurface3DTypeEnum
	ksSectorSurface               =16         # from enum ksMathSurface3DTypeEnum
	ksSmoothSurface               =31         # from enum ksMathSurface3DTypeEnum
	ksSphereSurface               =5          # from enum ksMathSurface3DTypeEnum
	ksSpiralSurface               =14         # from enum ksMathSurface3DTypeEnum
	ksSplineSurface               =19         # from enum ksMathSurface3DTypeEnum
	ksSweptSurface                =7          # from enum ksMathSurface3DTypeEnum
	ksTorusSurface                =6          # from enum ksMathSurface3DTypeEnum
	ksTriBezierSurface            =21         # from enum ksMathSurface3DTypeEnum
	ksTriSplineSurface            =22         # from enum ksMathSurface3DTypeEnum
	ksMResAxisAxisCoaxial         =1          # from enum ksMeasureResultEnum
	ksMResAxisAxisDistant         =4          # from enum ksMeasureResultEnum
	ksMResAxisAxisIntersect       =3          # from enum ksMeasureResultEnum
	ksMResAxisAxisParallel        =2          # from enum ksMeasureResultEnum
	ksMResAxisSurfColinear        =5          # from enum ksMeasureResultEnum
	ksMResAxisSurfDistant         =8          # from enum ksMeasureResultEnum
	ksMResAxisSurfIntersect       =7          # from enum ksMeasureResultEnum
	ksMResAxisSurfParallel        =6          # from enum ksMeasureResultEnum
	ksMResSurfSurfColinear        =9          # from enum ksMeasureResultEnum
	ksMResSurfSurfIntersecting    =11         # from enum ksMeasureResultEnum
	ksMResSurfSurfParallel        =10         # from enum ksMeasureResultEnum
	ksMResUnknown                 =0          # from enum ksMeasureResultEnum
	ksMACircular                  =2          # from enum ksMeshAroundPointTypeEnum
	ksMAHexagonal                 =3          # from enum ksMeshAroundPointTypeEnum
	ksMALinear                    =0          # from enum ksMeshAroundPointTypeEnum
	ksMAUVLinear                  =1          # from enum ksMeshAroundPointTypeEnum
	ksMPByPoints                  =0          # from enum ksMeshPointsSurfaceBuildingTypeEnum
	ksMPByPole                    =1          # from enum ksMeshPointsSurfaceBuildingTypeEnum
	ksModelDrawingElementAll      =65535      # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementAuxObjs  =256        # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementBackground=1          # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementCompBodies=16         # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementCompObjs =32         # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementEditor   =4096       # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementMeshCutter=16384      # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementNone     =0          # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementNotifyLibs=512        # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementWidgets  =8192       # from enum ksModelDrawingElementsEnum
	ksMOAllParam                  =1          # from enum ksModelObjectParamTypeEnum
	ksMOCurrentLSKAllParam        =3          # from enum ksModelObjectParamTypeEnum
	ksMOPartAllParam              =2          # from enum ksModelObjectParamTypeEnum
	ksArbitraryThicknesses        =0          # from enum ksMultiThicknessGroupTypeEnum
	ksSetsThicknesses             =1          # from enum ksMultiThicknessGroupTypeEnum
	ksFilterAll                   =0          # from enum ksObjectsFilter3DEnum
	ksFilterBodies                =7          # from enum ksObjectsFilter3DEnum
	ksFilterCAxis                 =5          # from enum ksObjectsFilter3DEnum
	ksFilterCPlanes               =4          # from enum ksObjectsFilter3DEnum
	ksFilterCS                    =11         # from enum ksObjectsFilter3DEnum
	ksFilterControlPoints         =12         # from enum ksObjectsFilter3DEnum
	ksFilterCurves                =10         # from enum ksObjectsFilter3DEnum
	ksFilterDesignations          =14         # from enum ksObjectsFilter3DEnum
	ksFilterEdges                 =2          # from enum ksObjectsFilter3DEnum
	ksFilterFaces                 =1          # from enum ksObjectsFilter3DEnum
	ksFilterParts                 =6          # from enum ksObjectsFilter3DEnum
	ksFilterPoints3D              =13         # from enum ksObjectsFilter3DEnum
	ksFilterSketches              =9          # from enum ksObjectsFilter3DEnum
	ksFilterSurfaces              =8          # from enum ksObjectsFilter3DEnum
	ksFilterThread                =15         # from enum ksObjectsFilter3DEnum
	ksFilterVertexs               =3          # from enum ksObjectsFilter3DEnum
	ksOGDraftPosition             =2          # from enum ksOffsetGapType
	ksOGLength                    =1          # from enum ksOffsetGapType
	ksOGParametrU                 =0          # from enum ksOffsetGapType
	ksOperationCut                =2          # from enum ksOperationResultEnum
	ksOperationIntersect          =3          # from enum ksOperationResultEnum
	ksOperationNewBody            =1          # from enum ksOperationResultEnum
	ksOperationUnion              =0          # from enum ksOperationResultEnum
	ksAxisOrientation             =0          # from enum ksOrientationTypeEnum
	ksEulerCorners                =1          # from enum ksOrientationTypeEnum
	ksOrientByObject              =2          # from enum ksOrientationTypeEnum
	ksAllParts                    =0          # from enum ksPart7CollectionTypeEnum
	ksUniqueParts                 =1          # from enum ksPart7CollectionTypeEnum
	ksATDisable                   =2          # from enum ksPartAccessTypeEnum
	ksATEditable                  =0          # from enum ksPartAccessTypeEnum
	ksATReadOnly                  =1          # from enum ksPartAccessTypeEnum
	ksATUncertainty               =-1         # from enum ksPartAccessTypeEnum
	ksCRAuto                      =0          # from enum ksPatternBasePointTypeEnum
	ksCRFirstObject               =2          # from enum ksPatternBasePointTypeEnum
	ksCRManual                    =1          # from enum ksPatternBasePointTypeEnum
	ksOrientationByNormal         =1          # from enum ksPatternExemplarsOrientationTypeEnum
	ksOrientationByObject         =2          # from enum ksPatternExemplarsOrientationTypeEnum
	ksOrientationSave             =0          # from enum ksPatternExemplarsOrientationTypeEnum
	ksOffsetByAngle               =3          # from enum ksPoint3DCurveParamTypeEnum
	ksOffsetByLen                 =2          # from enum ksPoint3DCurveParamTypeEnum
	ksOffsetByU                   =1          # from enum ksPoint3DCurveParamTypeEnum
	ksOffsetByCoords              =3          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetByCylinderCoords      =4          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetByLenFromObj          =2          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetBySphereCoords        =5          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetByUV                  =1          # from enum ksPoint3DSurfaceParamTypeEnum
	ksPCenter                     =4          # from enum ksPoint3DTypeEnum
	ksPCurve                      =5          # from enum ksPoint3DTypeEnum
	ksPCylindrCoord               =8          # from enum ksPoint3DTypeEnum
	ksPDisplace                   =2          # from enum ksPoint3DTypeEnum
	ksPIntersect                  =3          # from enum ksPoint3DTypeEnum
	ksPParamCoord                 =1          # from enum ksPoint3DTypeEnum
	ksPProjection                 =7          # from enum ksPoint3DTypeEnum
	ksPSphericCoord               =9          # from enum ksPoint3DTypeEnum
	ksPSurface                    =6          # from enum ksPoint3DTypeEnum
	ksPUnknown                    =0          # from enum ksPoint3DTypeEnum
	ksPAOCByParametricStep        =2          # from enum ksPointsArrOnCurveTypeEnum
	ksPAOCByPointsCount           =0          # from enum ksPointsArrOnCurveTypeEnum
	ksPAOCByStep                  =1          # from enum ksPointsArrOnCurveTypeEnum
	ksPAOSByAngularDeflection     =1          # from enum ksPointsArrOnSurfaceTypeEnum
	ksPAOSByLinearDeflection      =0          # from enum ksPointsArrOnSurfaceTypeEnum
	ksPAOSByMeshAroundPoint       =2          # from enum ksPointsArrOnSurfaceTypeEnum
	ksPAOSByPointsUVCount         =-1         # from enum ksPointsArrOnSurfaceTypeEnum
	ksPressFormingAllHeight       =0          # from enum ksPressFormingHeightTypeEnum
	ksPressFormingInHeight        =2          # from enum ksPressFormingHeightTypeEnum
	ksPressFormingOutHeight       =1          # from enum ksPressFormingHeightTypeEnum
	ksProcessFilterBodies         =0          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterExcludeExternalObjects=1000       # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterObjects        =2          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterOperations     =3          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterParts          =4          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterSurfaces       =1          # from enum ksProcessObjectsFilter3DEnum
	ksPOByLayer                   =2          # from enum ksProjectionOptionEnum
	ksPODisable                   =0          # from enum ksProjectionOptionEnum
	ksPOEnable                    =1          # from enum ksProjectionOptionEnum
	ksPOUndefined                 =-1         # from enum ksProjectionOptionEnum
	ksRTIndifferent               =1          # from enum ksRelationTypeEnum
	ksRTStrong                    =2          # from enum ksRelationTypeEnum
	ksRTUnknown                   =0          # from enum ksRelationTypeEnum
	ksRibSideDown                 =3          # from enum ksRibSideEnum
	ksRibSideLeft                 =0          # from enum ksRibSideEnum
	ksRibSideRight                =1          # from enum ksRibSideEnum
	ksRibSideUp                   =2          # from enum ksRibSideEnum
	ksRTAngle                     =0          # from enum ksRotatedTypeEnum
	ksRTSurface                   =2          # from enum ksRotatedTypeEnum
	ksRTVertex                    =1          # from enum ksRotatedTypeEnum
	ksRuledBodder1                =0          # from enum ksRuledBorderEnum
	ksRuledBodder2                =1          # from enum ksRuledBorderEnum
	ksRuledJoint1                 =0          # from enum ksRuledJointEnum
	ksRuledJoint2                 =1          # from enum ksRuledJointEnum
	ksSHRibBuildingDepthAngle     =2          # from enum ksSHRibBuildingTypeEnum
	ksSHRibBuildingHeightAngle    =0          # from enum ksSHRibBuildingTypeEnum
	ksSHRibBuildingTwoHeights     =1          # from enum ksSHRibBuildingTypeEnum
	ksSHRibCuttingU               =1          # from enum ksSHRibCutingTypeEnum
	ksSHRibCuttingV               =0          # from enum ksSHRibCutingTypeEnum
	ksSmAngle                     =2          # from enum ksSegmentationMethodEnum
	ksSmHeight                    =3          # from enum ksSegmentationMethodEnum
	ksSmLength                    =1          # from enum ksSegmentationMethodEnum
	ksSmQuantity                  =0          # from enum ksSegmentationMethodEnum
	ksSelectionNoBand             =0          # from enum ksSelectionBandMode
	ksSelectionWhenNoNearestObject=2          # from enum ksSelectionBandMode
	ksSheetMetalMatrix            =1          # from enum ksSheetMetalPunchBuildingTypeEnum
	ksSheetMetalPunch             =0          # from enum ksSheetMetalPunchBuildingTypeEnum
	ksSheetMetalPunchHeightByBody =0          # from enum ksSheetMetalPunchThicknessTypeEnum
	ksSheetMetalPunchHeightByValue=1          # from enum ksSheetMetalPunchThicknessTypeEnum
	ksShoulderAngle               =4          # from enum ksShoulderBuildingTypeEnum
	ksShoulderAngleOff            =-4         # from enum ksShoulderBuildingTypeEnum
	ksShoulderCircleByHeightRadius2=18         # from enum ksShoulderBuildingTypeEnum
	ksShoulderCircleByHeightWidth1=3          # from enum ksShoulderBuildingTypeEnum
	ksShoulderCircleByRadiusWidth1=17         # from enum ksShoulderBuildingTypeEnum
	ksShoulderHeight              =2          # from enum ksShoulderBuildingTypeEnum
	ksShoulderHeightOff           =-2         # from enum ksShoulderBuildingTypeEnum
	ksShoulderRadius2             =16         # from enum ksShoulderBuildingTypeEnum
	ksShoulderRadius2Off          =-16        # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByAngleWidth1Width2=13         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByAngleWidth1Width2Radius2=29         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidth1 =7          # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidth2 =14         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidth2Radius2=30         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidthRadius2=23         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighWidth1Width2=11         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighWidth1Width2Radius2=27         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUnknown             =0          # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByHeighAngleRadius2=22         # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByHeighAngleWidth1 =7          # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByHeighRadius2Width1=19         # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByRadius2AngleWidth1=21         # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth1              =1          # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth1Off           =-1         # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth2              =8          # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth2Off           =-8         # from enum ksShoulderBuildingTypeEnum
	ksShoulderCutingCircle        =0          # from enum ksShoulderCutingTypeEnum
	ksShoulderCutingU             =1          # from enum ksShoulderCutingTypeEnum
	ksShoulderCutingV             =2          # from enum ksShoulderCutingTypeEnum
	ksShoulderChopped             =2          # from enum ksShoulderTypeEnum
	ksShoulderClosed              =0          # from enum ksShoulderTypeEnum
	ksShoulderOpened              =1          # from enum ksShoulderTypeEnum
	ksSBFromSketch                =1          # from enum ksSketchBendBuildingTypeEnum
	ksSBSomeEdges                 =2          # from enum ksSketchBendBuildingTypeEnum
	ksRPBottomRight               =2          # from enum ksSpecRoughPlacementEnum
	ksRPTopLeft                   =0          # from enum ksSpecRoughPlacementEnum
	ksRPTopRight                  =1          # from enum ksSpecRoughPlacementEnum
	ksSHTByCurve                  =2          # from enum ksSpiral3DHeightTypeEnum
	ksSHTByObject                 =1          # from enum ksSpiral3DHeightTypeEnum
	ksSHTByValue                  =0          # from enum ksSpiral3DHeightTypeEnum
	ksSBTByStepAndHeight          =1          # from enum ksSpline3DBuildingTypeEnum
	ksSBTByStepAndTurnCount       =0          # from enum ksSpline3DBuildingTypeEnum
	ksSBTByTurnCountAndHeight     =2          # from enum ksSpline3DBuildingTypeEnum
	ksSDTByGeneratrixTiltAngle    =2          # from enum ksSpline3DDiameterTypeEnum
	ksSDTByObject                 =1          # from enum ksSpline3DDiameterTypeEnum
	ksSDTByValue                  =0          # from enum ksSpline3DDiameterTypeEnum
	ksSTByDirection               =1          # from enum ksSplineTangentEnum
	ksSTCurveU                    =2          # from enum ksSplineTangentEnum
	ksSTCurveV                    =3          # from enum ksSplineTangentEnum
	ksSTNone                      =0          # from enum ksSplineTangentEnum
	ksSTSurfaceCurve              =4          # from enum ksSplineTangentEnum
	ksSTTByParam                  =1          # from enum ksSplineTransitionTypeEnum
	ksSTTConstraint               =2          # from enum ksSplineTransitionTypeEnum
	ksSTTNone                     =0          # from enum ksSplineTransitionTypeEnum
	ksCollisionStep               =16         # from enum ksStepTypeEnum
	ksDeviationStep               =2          # from enum ksStepTypeEnum
	ksMetricStep                  =4          # from enum ksStepTypeEnum
	ksMipStep                     =32         # from enum ksStepTypeEnum
	ksParamStep                   =8          # from enum ksStepTypeEnum
	ksSpaceStep                   =1          # from enum ksStepTypeEnum
	ksTEFGeometryOnly             =1          # from enum ksTextExportFormEnum
	ksTEFTextOnly                 =0          # from enum ksTextExportFormEnum
	ksBaseProperties              =-1         # from enum ksTextureTypeEnum
	ksCutting                     =2          # from enum ksTextureTypeEnum
	ksRelief                      =1          # from enum ksTextureTypeEnum
	ksTexture                     =0          # from enum ksTextureTypeEnum
	ksTRCoefficient               =4          # from enum ksToleranceRecalcsEnum
	ksTRLowerLimit                =1          # from enum ksToleranceRecalcsEnum
	ksTRMiddle                    =3          # from enum ksToleranceRecalcsEnum
	ksTRTopLimit                  =2          # from enum ksToleranceRecalcsEnum
	ksTRUnknown                   =0          # from enum ksToleranceRecalcsEnum
	ksTRUser                      =5          # from enum ksToleranceRecalcsEnum
	ksTVBNormal                   =2          # from enum ksTransitionVectorIndexEnum
	ksTVNormal                    =1          # from enum ksTransitionVectorIndexEnum
	ksTVTangent                   =0          # from enum ksTransitionVectorIndexEnum
	ksUCDictanceAll               =2          # from enum ksUndercutDistanceTypeEnum
	ksUCDictanceIn                =1          # from enum ksUndercutDistanceTypeEnum
	ksUCDictanceOut               =0          # from enum ksUndercutDistanceTypeEnum
	ksCoefficient                 =0          # from enum ksUnfoldTypeEnum
	ksDecreaseBend                =2          # from enum ksUnfoldTypeEnum
	ksTableBends                  =3          # from enum ksUnfoldTypeEnum
	ksValueBend                   =1          # from enum ksUnfoldTypeEnum
	ksVector3D2Angles             =5          # from enum ksVector3DParametersTypeEnum
	ksVector3D2Vertex             =1          # from enum ksVector3DParametersTypeEnum
	ksVector3DAxis                =3          # from enum ksVector3DParametersTypeEnum
	ksVector3DCSAngle             =2          # from enum ksVector3DParametersTypeEnum
	ksVector3DCoefficients        =4          # from enum ksVector3DParametersTypeEnum
	ksVector3DCurve               =9          # from enum ksVector3DParametersTypeEnum
	ksVector3DEdge                =6          # from enum ksVector3DParametersTypeEnum
	ksVector3DPlane               =7          # from enum ksVector3DParametersTypeEnum
	ksVector3DScreen              =10         # from enum ksVector3DParametersTypeEnum
	ksVector3DSurface             =8          # from enum ksVector3DParametersTypeEnum
	ksVector3DUnknown             =0          # from enum ksVector3DParametersTypeEnum
	ksVPSUnknown                  =-1         # from enum ksViewProjectionScheme
	ksVPSUser                     =0          # from enum ksViewProjectionScheme
	ksVPSX90AxonometricISO        =6          # from enum ksViewProjectionScheme
	ksVPSXAxonometric             =3          # from enum ksViewProjectionScheme
	ksVPSY90AxonometricISO        =5          # from enum ksViewProjectionScheme
	ksVPSYAxonometric             =2          # from enum ksViewProjectionScheme
	ksVPSZ90AxonometricISO        =4          # from enum ksViewProjectionScheme
	ksVPSZAxonometric             =1          # from enum ksViewProjectionScheme
	ksVPDimetric                  =8          # from enum ksViewProjectionType
	ksVPDown                      =4          # from enum ksViewProjectionType
	ksVPFront                     =1          # from enum ksViewProjectionType
	ksVPIsometric                 =7          # from enum ksViewProjectionType
	ksVPLeft                      =5          # from enum ksViewProjectionType
	ksVPNone                      =-1         # from enum ksViewProjectionType
	ksVPNormalTo                  =0          # from enum ksViewProjectionType
	ksVPRear                      =2          # from enum ksViewProjectionType
	ksVPRight                     =6          # from enum ksViewProjectionType
	ksVPUnfold                    =9          # from enum ksViewProjectionType
	ksVPUp                        =3          # from enum ksViewProjectionType
	ksVPUser                      =10         # from enum ksViewProjectionType
	ksVSByLayer                   =2          # from enum ksVisibleStateEnum
	ksVSHidden                    =1          # from enum ksVisibleStateEnum
	ksVSUndefined                 =-1         # from enum ksVisibleStateEnum
	ksVSVisible                   =0          # from enum ksVisibleStateEnum
	ksZoneDivisionByPlanes        =1          # from enum ksZoneDivisionTypeEnum
	ksZoneDivisionRegular         =0          # from enum ksZoneDivisionTypeEnum
	ksZoneByObjects               =2          # from enum ksZoneTypeEnum
	ksZoneByPoints                =1          # from enum ksZoneTypeEnum
	ksZoneFree                    =0          # from enum ksZoneTypeEnum

RecordMap = {
}

CLSIDToClassMap = {
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
}


NamesToIIDMap = {
}

win32com.client.constants.__dicts__.append(constants.__dict__)




from setuptools import setup
from setuptools import setup

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(name='kompas3d',
      version='0.20.1',
      description='Kompas 3D packages',
      long_description = long_description,
      long_description_content_type = "text/markdown",
      packages=['kompas3d'],
      author="Asem Nurzhanova",
      author_email='asem.nurzhanova@outlook.com',
      url="https://www.ascon.net/",
      classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
      ],
      python_requires=">=3.8",
      zip_safe=False)